@@ -18,29 +18,32 @@
 #ifndef __APPENV_H__
 #define __APPENV_H__
 
-#include "gdk/gdkx.h"
-#include "gtk/gtk.h"
+#include <gtk/gtk.h>
 
-#define DISPLAY              ((Display *) GDK_DISPLAY())
+#include "gimpsetF.h"
 
-/*   important macros  */
-#define BOUNDS(a,x,y)  ((a < x) ? x : ((a > y) ? y : a))
-#define MINIMUM(x,y) ((x < y) ? x : y)
-#define MAXIMUM(x,y) ((x > y) ? x : y)
-
-typedef enum {
+typedef enum
+{
   MESSAGE_BOX,
-  CONSOLE
+  CONSOLE,
+  ERROR_CONSOLE
 } MessageHandlerType;
 
-extern int no_interface;
-extern int no_splash;
-extern int no_splash_image;
-extern int no_data;
-extern int be_verbose;
-extern int use_debug_handler;
-extern int console_messages;
-
+extern gboolean no_interface;
+extern gboolean no_splash;
+extern gboolean no_splash_image;
+extern gboolean no_data;
+extern gboolean be_verbose;
+extern gboolean use_debug_handler;
+extern gboolean console_messages;
+extern gboolean restore_session;
+extern gboolean double_speed;
+extern gboolean we_are_exiting;      /* this is used in session_get_window_info() */
+extern GimpSet *image_context;
 extern MessageHandlerType message_handler;
 
-#endif /*  APPENV_H  */
+#ifdef G_OS_WIN32
+gchar * quote_spaces (gchar *string);
+#endif
+
+#endif /*  __APPENV_H__  */
