@@ -129,7 +129,7 @@ tools_new_brightness_contrast (void)
    }
 
   tool = tools_new_tool (BRIGHTNESS_CONTRAST);
-  private = g_new (BrightnessContrast, 1);
+  private = g_new0 (BrightnessContrast, 1);
 
   tool->scroll_lock = TRUE;   /*  Disallow scrolling  */
   tool->preserve    = FALSE;  /*  Don't preserve on drawable change  */
@@ -231,7 +231,7 @@ brightness_contrast_dialog_new (void)
   gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
   /*  Create the brightness scale widget  */
-  label = gtk_label_new (_("Brightness"));
+  label = gtk_label_new (_("Brightness:"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 1.0);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
@@ -262,7 +262,7 @@ brightness_contrast_dialog_new (void)
   gtk_widget_show (abox);
 
   /*  Create the contrast scale widget  */
-  label = gtk_label_new (_("Contrast"));
+  label = gtk_label_new (_("Contrast:"));
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 1.0);
   gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
 		    GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
@@ -371,8 +371,7 @@ brightness_contrast_ok_callback (GtkWidget *widget,
 
   bcd = (BrightnessContrastDialog *) data;
 
-  if (GTK_WIDGET_VISIBLE (bcd->shell))
-    gtk_widget_hide (bcd->shell);
+  gimp_dialog_hide (bcd->shell);
 
   active_tool->preserve = TRUE;
 
@@ -404,8 +403,7 @@ brightness_contrast_cancel_callback (GtkWidget *widget,
 
   bcd = (BrightnessContrastDialog *) data;
 
-  if (GTK_WIDGET_VISIBLE (bcd->shell))
-    gtk_widget_hide (bcd->shell);
+  gimp_dialog_hide (bcd->shell);
 
   if (bcd->image_map)
     {
@@ -435,7 +433,16 @@ brightness_contrast_preview_update (GtkWidget *widget,
       brightness_contrast_preview (bcd);
     }
   else
-    bcd->preview = FALSE;
+    {
+      bcd->preview = FALSE;
+      if (bcd->image_map)
+	{
+	  active_tool->preserve = TRUE;
+	  image_map_clear (bcd->image_map);
+	  active_tool->preserve = FALSE;
+	  gdisplays_flush ();
+	}
+    }
 }
 
 static void
