@@ -13,16 +13,42 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 #ifndef  __BUCKET_FILL_H__
 #define  __BUCKET_FILL_H__
 
+#include "gimpimageF.h"
+#include "gimpdrawableF.h"
 #include "tools.h"
 
-void        bucket_fill_dialog      (void);
-Tool *      tools_new_bucket_fill   (void);
-void        tools_free_bucket_fill  (Tool *);
+typedef enum
+{
+  FG_BUCKET_FILL,
+  BG_BUCKET_FILL,
+  PATTERN_BUCKET_FILL
+} BucketFillMode;
 
+void        bucket_fill        (GimpImage      *gimage,
+				GimpDrawable   *drawable,
+				BucketFillMode  fill_mode,
+				gint            paint_mode,
+				gdouble         opacity,
+				gdouble         threshold,
+				gboolean        sample_merged,
+				gdouble         x,
+				gdouble         y);
+
+void        bucket_fill_region (BucketFillMode  fill_mode,
+				PixelRegion    *bufPR,
+				PixelRegion    *maskPR,
+				guchar         *col,
+				TempBuf        *pattern,
+				gint            off_x,
+				gint            off_y,
+				gboolean        has_alpha);
+
+Tool *      tools_new_bucket_fill   (void);
+void        tools_free_bucket_fill  (Tool *tool);
 
 #endif  /*  __BUCKET_FILL_H__  */
