@@ -15,6 +15,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+#include "config.h"
+
 #include <string.h>
 
 #include "appenv.h"
@@ -25,16 +27,16 @@
 #include "gdisplay.h"
 #include "gimpcontext.h"
 #include "gimpui.h"
-#include "interface.h"
-
-#include "config.h"
-#include "libgimp/gimpsizeentry.h"
-#include "libgimp/gimpmath.h"
-#include "libgimp/gimpintl.h"
+#include "parasitelist.h"
 
 #include "channel_pvt.h"
 #include "layer_pvt.h"
 
+#include "libgimp/gimpmath.h"
+
+#include "libgimp/gimpintl.h"
+
+
 #define ENTRY_WIDTH  60
 
 typedef struct _OffsetDialog OffsetDialog;
@@ -165,7 +167,7 @@ channel_ops_offset (GimpImage* gimage)
 
   /*  The fill options  */
   frame =
-    gimp_radio_group_new2 (TRUE, _("Fill Options"),
+    gimp_radio_group_new2 (TRUE, _("Fill Type"),
 			   gimp_radio_button_update,
 			   &off_d->fill_type, (gpointer) off_d->fill_type,
 
@@ -517,7 +519,8 @@ duplicate (GimpImage *gimage)
   Channel *active_channel = NULL;
   GimpDrawable *new_floating_sel_drawable = NULL;
   GimpDrawable *floating_sel_drawable = NULL;
-
+  ParasiteList *parasites;
+  PathList *paths;
   gint count;
 
   gimp_add_busy_cursors_until_idle ();
@@ -606,8 +609,10 @@ duplicate (GimpImage *gimage)
     }
 
   /*  Copy the selection mask  */
-  pixel_region_init (&srcPR, drawable_data (GIMP_DRAWABLE(gimage->selection_mask)), 0, 0, gimage->width, gimage->height, FALSE);
-  pixel_region_init (&destPR, drawable_data (GIMP_DRAWABLE(new_gimage->selection_mask)), 0, 0, gimage->width, gimage->height, TRUE);
+  pixel_region_init (&srcPR, drawable_data (GIMP_DRAWABLE(gimage->selection_mask)), 
+		     0, 0, gimage->width, gimage->height, FALSE);
+  pixel_region_init (&destPR, drawable_data (GIMP_DRAWABLE(new_gimage->selection_mask)), 
+		     0, 0, gimage->width, gimage->height, TRUE);
   copy_region (&srcPR, &destPR);
   new_gimage->selection_mask->bounds_known = FALSE;
   new_gimage->selection_mask->boundary_known = FALSE;
@@ -659,6 +664,30 @@ duplicate (GimpImage *gimage)
     new_gimage->qmask_color[count] = gimage->qmask_color[count];
   new_gimage->qmask_opacity = gimage->qmask_opacity;
 
+  /* Copy parasites */
+  parasites = gimage->parasites;
+  if (parasites)
+    new_gimage->parasites = parasite_list_copy (parasites);
+
+  /* Copy paths */
+  paths = gimp_image_get_paths (gimage);
+  if (paths)
+    {
+      GSList *plist = NULL;
+      GSList *new_plist = NULL;
+      Path *path;
+      PathList *new_paths;
+      
+      for (plist = paths->bz_paths; plist; plist = plist->next)
+	{
+	  path = plist->data;
+	  new_plist = g_slist_append (new_plist, path_copy (new_gimage, path));
+	}
+      
+      new_paths = path_list_new (new_gimage, paths->last_selected_row, new_plist);
+      gimp_image_set_paths (new_gimage, new_paths);
+    }
+
   gimage_enable_undo (new_gimage);
 
   return new_gimage;
