@@ -15,14 +15,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
-#include <math.h>
+
 #include "appenv.h"
-#include "buildmenu.h"
-#include "colormaps.h"
 #include "drawable.h"
 #include "gdisplay.h"
 #include "histogramwidget.h"
@@ -33,9 +34,10 @@
 #include "gimplut.h"
 #include "lut_funcs.h"
 
-#include "config.h"
-#include "libgimp/gimpintl.h"
 #include "libgimp/gimpenv.h"
+#include "libgimp/gimpmath.h"
+
+#include "libgimp/gimpintl.h"
 
 #define LOW_INPUT          0x1
 #define GAMMA              0x2
@@ -92,6 +94,7 @@ struct _LevelsDialog
   GimpHistogram   *hist;
 
   GimpDrawable   *drawable;
+
   ImageMap        image_map;
 
   gint            color;
@@ -121,6 +124,8 @@ static LevelsDialog *levels_dialog = NULL;
 static GtkWidget *file_dlg = NULL;
 static gboolean   load_save;
 
+static GtkWidget *color_option_items[5];
+
 /*  levels action functions  */
 static void   levels_control (Tool *, ToolAction, gpointer);
 
@@ -129,11 +134,7 @@ static LevelsDialog * levels_dialog_new (void);
 static void   levels_calculate_transfers           (LevelsDialog *);
 static void   levels_update                        (LevelsDialog *, gint);
 static void   levels_preview                       (LevelsDialog *);
-static void   levels_value_callback                (GtkWidget *, gpointer);
-static void   levels_red_callback                  (GtkWidget *, gpointer);
-static void   levels_green_callback                (GtkWidget *, gpointer);
-static void   levels_blue_callback                 (GtkWidget *, gpointer);
-static void   levels_alpha_callback                (GtkWidget *, gpointer);
+static void   levels_channel_callback              (GtkWidget *, gpointer);
 static void   levels_reset_callback                (GtkWidget *, gpointer);
 static void   levels_ok_callback                   (GtkWidget *, gpointer);
 static void   levels_cancel_callback               (GtkWidget *, gpointer);
@@ -151,12 +152,12 @@ static gint   levels_input_da_events               (GtkWidget *, GdkEvent *,
 static gint   levels_output_da_events              (GtkWidget *, GdkEvent *,
 						    LevelsDialog *);
 
-static void   make_file_dlg                        (gpointer);
-static void   file_ok_callback                     (GtkWidget *, gpointer);
-static void   file_cancel_callback                 (GtkWidget *, gpointer);
+static void   file_dialog_create                   (GtkWidget *);
+static void   file_dialog_ok_callback              (GtkWidget *, gpointer);
+static void   file_dialog_cancel_callback          (GtkWidget *, gpointer);
 
-static gboolean  read_levels_from_file             (FILE *f);
-static void      write_levels_to_file              (FILE *f);
+static gboolean  levels_read_from_file             (FILE *f);
+static void      levels_write_to_file              (FILE *f);
 
 
 /*  levels action functions  */
@@ -198,7 +199,7 @@ tools_new_levels (void)
     }
 
   tool = tools_new_tool (LEVELS);
-  private = g_new (Levels, 1);
+  private = g_new0 (Levels, 1);
 
   tool->scroll_lock = TRUE;   /*  Disallow scrolling  */
   tool->preserve    = FALSE;  /*  Don't preserve on drawable change  */
@@ -224,16 +225,6 @@ tools_free_levels (Tool *tool)
   g_free (private);
 }
 
-static MenuItem color_option_items[] =
-{
-  { N_("Value"), 0, 0, levels_value_callback, NULL, NULL, NULL },
-  { N_("Red"), 0, 0, levels_red_callback, NULL, NULL, NULL },
-  { N_("Green"), 0, 0, levels_green_callback, NULL, NULL, NULL },
-  { N_("Blue"), 0, 0, levels_blue_callback, NULL, NULL, NULL },
-  { N_("Alpha"), 0, 0, levels_alpha_callback, NULL, NULL, NULL },
-  { NULL, 0, 0, NULL, NULL, NULL, NULL }
-};
-
 void
 levels_initialize (GDisplay *gdisp)
 {
@@ -268,21 +259,20 @@ levels_initialize (GDisplay *gdisp)
   levels_dialog->image_map = image_map_create (gdisp, levels_dialog->drawable);
 
   /* check for alpha channel */
-  if (drawable_has_alpha (levels_dialog->drawable))
-    gtk_widget_set_sensitive (color_option_items[4].widget, TRUE);
-  else 
-    gtk_widget_set_sensitive (color_option_items[4].widget, FALSE);
+  gtk_widget_set_sensitive (color_option_items[4],
+			    drawable_has_alpha (levels_dialog->drawable));
   
   /*  hide or show the channel menu based on image type  */
   if (levels_dialog->color)
     for (i = 0; i < 4; i++) 
-       gtk_widget_set_sensitive (color_option_items[i].widget, TRUE);
+       gtk_widget_set_sensitive (color_option_items[i], TRUE);
   else 
     for (i = 1; i < 4; i++) 
-       gtk_widget_set_sensitive (color_option_items[i].widget, FALSE);
+       gtk_widget_set_sensitive (color_option_items[i], FALSE);
 
   /* set the current selection */
-  gtk_option_menu_set_history (GTK_OPTION_MENU (levels_dialog->channel_menu), 0);
+  gtk_option_menu_set_history (GTK_OPTION_MENU (levels_dialog->channel_menu),
+			       levels_dialog->channel);
 
 
   levels_update (levels_dialog, LOW_INPUT | GAMMA | HIGH_INPUT | LOW_OUTPUT | HIGH_OUTPUT | DRAW);
@@ -327,24 +317,20 @@ levels_dialog_new (void)
   GtkWidget *frame;
   GtkWidget *toggle;
   GtkWidget *channel_hbox;
-  GtkWidget *menu;
   GtkWidget *hbbox;
   GtkWidget *button;
   GtkWidget *spinbutton;
   GtkObject *data;
-  gint i;
 
   ld = g_new (LevelsDialog, 1);
+  ld->channel = HISTOGRAM_VALUE;
   ld->preview = TRUE;
   ld->lut     = gimp_lut_new ();
   ld->hist    = gimp_histogram_new ();
 
-  for (i = 0; i < 5; i++)
-    color_option_items [i].user_data = (gpointer) ld;
-
   /*  The shell and main vbox  */
   ld->shell = gimp_dialog_new (_("Levels"), "levels",
-			       tools_help_func, NULL,
+			       tools_help_func, tool_info[LEVELS].private_tip,
 			       GTK_WIN_POS_NONE,
 			       FALSE, TRUE, FALSE,
 
@@ -374,15 +360,23 @@ levels_dialog_new (void)
 
   label = gtk_label_new (_("Modify Levels for Channel:"));
   gtk_box_pack_start (GTK_BOX (channel_hbox), label, FALSE, FALSE, 0);
-
-  menu = build_menu (color_option_items, NULL);
-  ld->channel_menu = gtk_option_menu_new ();
-  gtk_box_pack_start (GTK_BOX (channel_hbox), ld->channel_menu, FALSE, FALSE, 0);
-
   gtk_widget_show (label);
+
+  ld->channel_menu = gimp_option_menu_new2
+    (FALSE, levels_channel_callback,
+     ld, (gpointer) ld->channel,
+
+     _("Value"), (gpointer) HISTOGRAM_VALUE, &color_option_items[0],
+     _("Red"),   (gpointer) HISTOGRAM_RED,   &color_option_items[1],
+     _("Green"), (gpointer) HISTOGRAM_GREEN, &color_option_items[2],
+     _("Blue"),  (gpointer) HISTOGRAM_BLUE,  &color_option_items[3],
+     _("Alpha"), (gpointer) HISTOGRAM_ALPHA, &color_option_items[4],
+
+     NULL);
+  gtk_box_pack_start (GTK_BOX (channel_hbox), ld->channel_menu, FALSE, FALSE, 0);
   gtk_widget_show (ld->channel_menu);
+
   gtk_widget_show (channel_hbox);
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (ld->channel_menu), menu);
 
   /*  Horizontal box for input levels spinbuttons  */
   hbox = gtk_hbox_new (FALSE, 4);
@@ -607,7 +601,7 @@ levels_dialog_new (void)
 
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      GTK_SIGNAL_FUNC (levels_load_callback),
-		      NULL);
+		      ld->shell);
 
   gtk_widget_show (button);
 
@@ -617,7 +611,7 @@ levels_dialog_new (void)
 
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      GTK_SIGNAL_FUNC (levels_save_callback),
-		      NULL);
+		      ld->shell);
 
   gtk_widget_show (button);
 
@@ -858,103 +852,38 @@ levels_preview (LevelsDialog *ld)
 {
   if (!ld->image_map)
     {
-      g_warning ("No image map");
+      g_warning ("levels_preview: No Image Map");
       return;
     }
-
+  if (!ld->preview)
+    return;
   active_tool->preserve = TRUE;
-  image_map_apply (ld->image_map,  (ImageMapApplyFunc)gimp_lut_process_2,
+  image_map_apply (ld->image_map, (ImageMapApplyFunc) gimp_lut_process_2,
 		   (void *) ld->lut);
   active_tool->preserve = FALSE;
 }
 
 static void
-levels_value_callback (GtkWidget *widget,
-		       gpointer   data)
+levels_channel_callback (GtkWidget *widget,
+			 gpointer   data)
 {
   LevelsDialog *ld;
 
   ld = (LevelsDialog *) data;
 
-  if (ld->channel != HISTOGRAM_VALUE)
-    {
-      ld->channel = HISTOGRAM_VALUE;
-      histogram_widget_channel (ld->histogram, ld->channel);
-      levels_update (ld, ALL);
-    }
-}
+  gimp_menu_item_update (widget, &ld->channel);
 
-static void
-levels_red_callback (GtkWidget *widget,
-		     gpointer   data)
-{
-  LevelsDialog *ld;
-
-  ld = (LevelsDialog *) data;
-
-  if (ld->channel != HISTOGRAM_RED)
-    {
-      ld->channel = HISTOGRAM_RED;
-      histogram_widget_channel (ld->histogram, ld->channel);
-      levels_update (ld, ALL);
-    }
-}
-
-static void
-levels_green_callback (GtkWidget *widget,
-		       gpointer   data)
-{
-  LevelsDialog *ld;
-
-  ld = (LevelsDialog *) data;
-
-  if (ld->channel != HISTOGRAM_GREEN)
-    {
-      ld->channel = HISTOGRAM_GREEN;
-      histogram_widget_channel (ld->histogram, ld->channel);
-      levels_update (ld, ALL);
-    }
-}
-
-static void
-levels_blue_callback (GtkWidget *widget,
-		      gpointer   data)
-{
-  LevelsDialog *ld;
-
-  ld = (LevelsDialog *) data;
-
-  if (ld->channel != HISTOGRAM_BLUE)
-    {
-      ld->channel = HISTOGRAM_BLUE;
-      histogram_widget_channel (ld->histogram, ld->channel);
-      levels_update (ld, ALL);
-    }
-}
-
-static void
-levels_alpha_callback (GtkWidget *widget,
-		       gpointer   data)
-{
-  LevelsDialog *ld;
-
-  ld = (LevelsDialog *) data;
-
-  if (ld->channel != HISTOGRAM_ALPHA)
-    {
-      ld->channel = HISTOGRAM_ALPHA;
-      histogram_widget_channel (ld->histogram, ld->channel);
-      levels_update (ld, ALL);
-    }
+  histogram_widget_channel (ld->histogram, ld->channel);
+  levels_update (ld, ALL);
 }
 
 static void
 levels_adjust_channel (LevelsDialog    *ld,
 		       GimpHistogram   *hist,
-		       int              channel)
+		       gint             channel)
 {
-  int i;
-  double count, new_count, percentage, next_percentage;
+  gint i;
+  gdouble count, new_count, percentage, next_percentage;
 
   ld->gamma[channel]       = 1.0;
   ld->low_output[channel]  = 0;
@@ -1009,17 +938,28 @@ levels_reset_callback (GtkWidget *widget,
 		       gpointer   data)
 {
   LevelsDialog *ld;
+  int channel;
+  int maxChannels;
 
   ld = (LevelsDialog *) data;
 
-  ld->low_input[ld->channel]   = 0;
-  ld->gamma[ld->channel]       = 1.0;
-  ld->high_input[ld->channel]  = 255;
-  ld->low_output[ld->channel]  = 0;
-  ld->high_output[ld->channel] = 255;
-
+  if (ld->color)
+    maxChannels = 4;
+  else
+    maxChannels = 1;
+  
+  for (channel = 0; channel < maxChannels; channel++)
+    {
+      ld->low_input[channel]   = 0;
+      ld->gamma[channel]       = 1.0;
+      ld->high_input[channel]  = 255;
+      ld->low_output[channel]  = 0;
+      ld->high_output[channel] = 255;
+      
+      levels_adjust_channel (ld, ld->hist, channel + 1);
+    }
   levels_update (ld, ALL);
-
+  
   if (ld->preview)
     levels_preview (ld);
 }
@@ -1032,8 +972,7 @@ levels_ok_callback (GtkWidget *widget,
 
   ld = (LevelsDialog *) data;
 
-  if (GTK_WIDGET_VISIBLE (ld->shell))
-    gtk_widget_hide (ld->shell);
+  gimp_dialog_hide (ld->shell);
 
   active_tool->preserve = TRUE;
 
@@ -1065,8 +1004,7 @@ levels_cancel_callback (GtkWidget *widget,
 
   ld = (LevelsDialog *) data;
 
-  if (GTK_WIDGET_VISIBLE (ld->shell))
-    gtk_widget_hide (ld->shell);
+  gimp_dialog_hide (ld->shell);
 
   if (ld->image_map)
     {
@@ -1116,7 +1054,7 @@ levels_load_callback (GtkWidget *widget,
 		      gpointer   data)
 {
   if (!file_dlg)
-    make_file_dlg (NULL);
+    file_dialog_create (GTK_WIDGET (data));
   else if (GTK_WIDGET_VISIBLE (file_dlg)) 
     return;
 
@@ -1131,7 +1069,7 @@ levels_save_callback (GtkWidget *widget,
 		      gpointer   data)
 {
   if (!file_dlg)
-    make_file_dlg (NULL);
+    file_dialog_create (GTK_WIDGET (data));
   else if (GTK_WIDGET_VISIBLE (file_dlg)) 
     return;
 
@@ -1155,7 +1093,17 @@ levels_preview_update (GtkWidget *widget,
       levels_preview (ld);
     }
   else
-    ld->preview = FALSE;
+    {
+      ld->preview = FALSE;
+      if (ld->image_map)
+	{
+	  active_tool->preserve = TRUE;
+	  image_map_clear (ld->image_map);
+	  active_tool->preserve = FALSE;
+	  gdisplays_flush ();
+	}
+    }
+
 }
 
 static void
@@ -1452,7 +1400,7 @@ levels_output_da_events (GtkWidget    *widget,
 }
 
 static void
-make_file_dlg (gpointer data)
+file_dialog_create (GtkWidget *parent)
 {
   gchar *temp;
 
@@ -1464,24 +1412,31 @@ make_file_dlg (gpointer data)
   gtk_container_set_border_width (GTK_CONTAINER (GTK_FILE_SELECTION (file_dlg)->button_area), 2);
 
   gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_dlg)->cancel_button),
-		      "clicked", GTK_SIGNAL_FUNC (file_cancel_callback),
-		      data);
+		      "clicked", GTK_SIGNAL_FUNC (file_dialog_cancel_callback),
+		      NULL);
   gtk_signal_connect (GTK_OBJECT (file_dlg), "delete_event",
-		      GTK_SIGNAL_FUNC (file_cancel_callback),
-		      data);
+		      GTK_SIGNAL_FUNC (file_dialog_cancel_callback),
+		      NULL);
   gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_dlg)->ok_button),
-		      "clicked", GTK_SIGNAL_FUNC (file_ok_callback),
-		      data);
+		      "clicked", GTK_SIGNAL_FUNC (file_dialog_ok_callback),
+		      NULL);
+
+  gtk_signal_connect (GTK_OBJECT (parent), "unmap",
+		      GTK_SIGNAL_FUNC (file_dialog_cancel_callback),
+		      NULL);
 
   temp = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "levels" G_DIR_SEPARATOR_S,
       			  gimp_directory ());
   gtk_file_selection_set_filename (GTK_FILE_SELECTION (file_dlg), temp);
   g_free (temp);
+
+  gimp_help_connect_help_accel (file_dlg, tools_help_func,
+				tool_info[LEVELS].private_tip);
 }
 
 static void
-file_ok_callback (GtkWidget *widget,
-		  gpointer   data)
+file_dialog_ok_callback (GtkWidget *widget,
+			 gpointer   data)
 {
   FILE  *f;
   gchar *filename;
@@ -1498,7 +1453,7 @@ file_ok_callback (GtkWidget *widget,
 	  return;
 	}
 
-      if (!read_levels_from_file (f))
+      if (!levels_read_from_file (f))
 	{
 	  g_message (("Error in reading file %s"), filename);
 	  return;
@@ -1516,23 +1471,22 @@ file_ok_callback (GtkWidget *widget,
 	  return;
 	}
 
-      write_levels_to_file (f);
+      levels_write_to_file (f);
 
       fclose (f);
     }
-
-  gtk_widget_hide (file_dlg);
+  file_dialog_cancel_callback (file_dlg, NULL);
 }
 
 static void
-file_cancel_callback (GtkWidget *widget,
-		      gpointer   data)
+file_dialog_cancel_callback (GtkWidget *widget,
+			     gpointer   data)
 {
-  gtk_widget_hide (file_dlg);
+  gimp_dialog_hide (file_dlg);
 }
 
 static gboolean
-read_levels_from_file (FILE *f)
+levels_read_from_file (FILE *f)
 {
   int low_input[5];
   int high_input[5];
@@ -1586,7 +1540,7 @@ read_levels_from_file (FILE *f)
 }
 
 static void
-write_levels_to_file (FILE *f)
+levels_write_to_file (FILE *f)
 {
   int i;
 
