@@ -15,6 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
+
 #include "config.h"
 
 #include <string.h>
@@ -22,6 +23,7 @@
 #include "appenv.h"
 #include "colormaps.h"
 #include "context_manager.h"
+#include "cursorutil.h"
 #include "gdisplay_ops.h"
 #include "gdisplay.h"
 #include "gimprc.h"
@@ -32,14 +34,14 @@
 #include "session.h"
 #include "tile_cache.h"
 
-#include "libgimp/gimpchainbutton.h"
-#include "libgimp/gimpfileselection.h"
-#include "libgimp/gimppatheditor.h"
-#include "libgimp/gimpsizeentry.h"
 #include "libgimp/gimplimits.h"
+#include "libgimp/gimpmath.h"
 
 #include "libgimp/gimpintl.h"
 
+/* gimprc will be parsed with a buffer size of 1024, 
+   so don't set this too large */
+#define MAX_COMMENT_LENGTH 512
 
 typedef enum
 {
@@ -58,9 +60,8 @@ static void        file_prefs_cancel_callback       (GtkWidget *, GtkWidget *);
 static void  file_prefs_toggle_callback             (GtkWidget *, gpointer);
 static void  file_prefs_preview_size_callback       (GtkWidget *, gpointer);
 static void  file_prefs_nav_preview_size_callback   (GtkWidget *, gpointer);
-static void  file_prefs_mem_size_callback           (GtkWidget *, gpointer);
-static void  file_prefs_mem_size_unit_callback      (GtkWidget *, gpointer);
 static void  file_prefs_string_callback             (GtkWidget *, gpointer);
+static void  file_prefs_text_callback               (GtkWidget *, gpointer);
 static void  file_prefs_filename_callback           (GtkWidget *, gpointer);
 static void  file_prefs_path_callback               (GtkWidget *, gpointer);
 static void  file_prefs_clear_session_info_callback (GtkWidget *, gpointer);
@@ -97,9 +98,11 @@ static gdouble            old_default_xresolution;
 static gdouble            old_default_yresolution;
 static GimpUnit           old_default_resolution_units;
 static gint               old_default_type;
+static gchar *            old_default_comment;
 static gint               old_default_dot_for_dot;
 static gint               old_stingy_memory_use;
-static gint               old_tile_cache_size;
+static guint              old_tile_cache_size;
+static gint               old_min_colors;
 static gint               old_install_cmap;
 static gint               old_cycled_marching_ants;
 static gint               old_last_opened_size;
@@ -118,7 +121,7 @@ static gint               old_using_xserver_resolution;
 static gint               old_num_processors;
 static gchar *            old_image_title_format;
 static gint               old_global_paint_options;
-static gint               old_max_new_image_size;
+static guint              old_max_new_image_size;
 static gint               old_thumbnail_mode;
 static gint 	          old_show_indicators;
 static gint	          old_trust_dirty_flag;
@@ -126,13 +129,15 @@ static gint               old_use_help;
 static gint               old_nav_window_per_display;
 static gint               old_info_window_follows_mouse;
 static gint               old_help_browser;
+static gint               old_cursor_mode;
+static gint               old_default_threshold;
 
 /*  variables which can't be changed on the fly  */
 static gint               edit_stingy_memory_use;
+static gint               edit_min_colors;
 static gint               edit_install_cmap;
 static gint               edit_cycled_marching_ants;
 static gint               edit_last_opened_size;
-static gint               edit_num_processors;
 static gint               edit_show_indicators;
 static gint               edit_nav_window_per_display;
 static gint               edit_info_window_follows_mouse;
@@ -147,7 +152,7 @@ static gchar *            edit_plug_in_path   = NULL;
 static gchar *            edit_module_path    = NULL;
 
 /*  variables which will be changed _after_ closing the dialog  */
-static gint               edit_tile_cache_size;
+static guint              edit_tile_cache_size;
 
 static GtkWidget *        prefs_dlg = NULL;
 
@@ -160,10 +165,10 @@ static GtkWidget *        prefs_dlg = NULL;
    so they're set on the fly is not hard).
 
    stingy-memory-use
+   min-colors
    install-cmap
    cycled-marching-ants
    last-opened-size
-   num-processors
    show-indicators
    nav-window-per-display
    info_window_follows_mouse
@@ -188,7 +193,7 @@ static GtkWidget *        prefs_dlg = NULL;
    Here are the remaining issues as I see them:
 
    Still no settings for default-gradient, default-palette,
-   gamma-correction, color-cube.
+   gamma-correction.
 
    No widget for confirm-on-close although a lot of stuff is there.
 
@@ -296,19 +301,19 @@ file_prefs_check_settings (void)
       return PREFS_CORRUPT;
     }
 
-  if (edit_num_processors < 1 || edit_num_processors > 30) 
+  if (num_processors < 1 || num_processors > 30) 
     {
       g_message (_("Error: Number of processors must be between 1 and 30."));
-      edit_num_processors = old_num_processors;
+      num_processors = old_num_processors;
       return PREFS_CORRUPT;
     }
 
   /*  ...then check if we need a restart notification  */
   if (edit_stingy_memory_use         != old_stingy_memory_use         ||
+      edit_min_colors                != old_min_colors                ||
       edit_install_cmap              != old_install_cmap              ||
       edit_cycled_marching_ants      != old_cycled_marching_ants      ||
       edit_last_opened_size          != old_last_opened_size          ||
-      edit_num_processors            != old_num_processors            ||
       edit_show_indicators           != old_show_indicators           ||
       edit_nav_window_per_display    != old_nav_window_per_display    ||
       edit_info_window_follows_mouse != old_info_window_follows_mouse ||
@@ -436,10 +441,10 @@ file_prefs_save_callback (GtkWidget *widget,
   PrefsState state;
 
   gint   save_stingy_memory_use;
+  gint   save_min_colors;
   gint   save_install_cmap;
   gint   save_cycled_marching_ants;
   gint   save_last_opened_size;
-  gint   save_num_processors;
   gint   save_show_indicators;
   gint   save_nav_window_per_display;
   gint   save_info_window_follows_mouse;
@@ -485,10 +490,10 @@ file_prefs_save_callback (GtkWidget *widget,
 
   /*  Save variables so that we can restore them later  */
   save_stingy_memory_use         = stingy_memory_use;
+  save_min_colors                = min_colors;
   save_install_cmap              = install_cmap;
   save_cycled_marching_ants      = cycled_marching_ants;
   save_last_opened_size          = last_opened_size;
-  save_num_processors            = num_processors;
   save_show_indicators           = show_indicators;
   save_nav_window_per_display    = nav_window_per_display;
   save_info_window_follows_mouse = info_window_follows_mouse;
@@ -589,6 +594,10 @@ file_prefs_save_callback (GtkWidget *widget,
     {
       update = g_list_append (update, "default-image-type");
     }
+  if (file_prefs_strcmp (default_comment, old_default_comment))
+    {
+      update = g_list_append (update, "default-comment");
+    }
   if (default_dot_for_dot != old_default_dot_for_dot)
     {
       update = g_list_append (update, "default-dot-for-dot");
@@ -662,7 +671,18 @@ file_prefs_save_callback (GtkWidget *widget,
     {
       update = g_list_append (update, "help-browser");
     }
-
+  if (cursor_mode != old_cursor_mode)
+    {
+      update = g_list_append (update, "cursor-mode");
+    }
+  if (default_threshold != old_default_threshold)
+    {
+      update = g_list_append (update, "default-threshold");
+    }
+  if (num_processors != old_num_processors)
+    {
+      update = g_list_append (update, "num-processors");
+    }
 
   /*  values which can't be changed on the fly  */
   if (edit_stingy_memory_use != old_stingy_memory_use)
@@ -670,6 +690,11 @@ file_prefs_save_callback (GtkWidget *widget,
       stingy_memory_use = edit_stingy_memory_use;
       update = g_list_append (update, "stingy-memory-use");
     }
+  if (edit_min_colors != old_min_colors)
+    {
+      min_colors = edit_min_colors;
+      update = g_list_append (update, "min-colors");
+    }
   if (edit_install_cmap != old_install_cmap)
     {
       install_cmap = edit_install_cmap;
@@ -685,11 +710,6 @@ file_prefs_save_callback (GtkWidget *widget,
       last_opened_size = edit_last_opened_size;
       update = g_list_append (update, "last-opened-size");
     }
-  if (edit_num_processors != old_num_processors)
-    {
-      num_processors = edit_num_processors;
-      update = g_list_append (update, "num-processors");
-    }
   if (edit_show_indicators != old_show_indicators)
     {
       show_indicators = edit_show_indicators;
@@ -771,10 +791,10 @@ file_prefs_save_callback (GtkWidget *widget,
 
   /*  restore variables which must not change  */
   stingy_memory_use         = save_stingy_memory_use;
+  min_colors                = save_min_colors;
   install_cmap              = save_install_cmap;
   cycled_marching_ants      = save_cycled_marching_ants;
   last_opened_size          = save_last_opened_size;
-  num_processors            = save_num_processors;
   show_indicators           = save_show_indicators;
   nav_window_per_display    = save_nav_window_per_display;
   info_window_follows_mouse = save_info_window_follows_mouse;
@@ -832,6 +852,9 @@ file_prefs_cancel_callback (GtkWidget *widget,
   trust_dirty_flag         = old_trust_dirty_flag;
   use_help                 = old_use_help;
   help_browser             = old_help_browser;
+  cursor_mode              = old_cursor_mode;
+  default_threshold        = old_default_threshold;
+  num_processors           = old_num_processors;
 
   /*  restore variables which need some magic  */
   if (preview_size != old_preview_size)
@@ -858,15 +881,16 @@ file_prefs_cancel_callback (GtkWidget *widget,
     }
 
   file_prefs_strset (&image_title_format, old_image_title_format);
+  file_prefs_strset (&default_comment, old_default_comment);
 
   context_manager_set_global_paint_options (old_global_paint_options);
 
   /*  restore values which need a restart  */
   edit_stingy_memory_use         = old_stingy_memory_use;
+  edit_min_colors                = old_min_colors;
   edit_install_cmap              = old_install_cmap;
   edit_cycled_marching_ants      = old_cycled_marching_ants;
   edit_last_opened_size          = old_last_opened_size;
-  edit_num_processors            = old_num_processors;
   edit_show_indicators           = old_show_indicators;
   edit_nav_window_per_display    = old_nav_window_per_display;
   edit_info_window_follows_mouse = old_info_window_follows_mouse;
@@ -922,6 +946,7 @@ file_prefs_toggle_callback (GtkWidget *widget,
 	   data == &interpolation_type ||
            data == &trust_dirty_flag   ||
 	   data == &help_browser       ||
+	   data == &cursor_mode        ||
 	   data == &default_type)
     {
       *val = (gint) gtk_object_get_user_data (GTK_OBJECT (widget));
@@ -972,67 +997,6 @@ file_prefs_nav_preview_size_callback (GtkWidget *widget,
   gdisplays_nav_preview_resized ();
 }
 
-static void
-file_prefs_mem_size_callback (GtkWidget *widget,
-			      gpointer   data)
-{
-  gint *mem_size;
-  gint  divided_mem_size;
-  gint  mem_size_unit;
-
-  if (! (mem_size = gtk_object_get_data (GTK_OBJECT (widget), "mem_size")))
-    return;
-
-  divided_mem_size = (int) gtk_object_get_data (GTK_OBJECT (widget),
-						"divided_mem_size");
-  mem_size_unit = (int) gtk_object_get_data (GTK_OBJECT (widget),
-					     "mem_size_unit");
-
-  divided_mem_size = GTK_ADJUSTMENT (widget)->value;
-  *mem_size = divided_mem_size * mem_size_unit;
-
-  gtk_object_set_data (GTK_OBJECT (widget), "divided_mem_size",
-		       (gpointer) divided_mem_size);
-}
-
-static void
-file_prefs_mem_size_unit_callback (GtkWidget *widget,
-				   gpointer   data)
-{
-  GtkObject *adjustment;
-  gint  new_unit;
-  gint *mem_size;
-  gint  divided_mem_size;
-  gint  mem_size_unit;
-
-  adjustment = GTK_OBJECT (data);
-
-  new_unit = (int) gtk_object_get_user_data (GTK_OBJECT (widget));
-
-  if (! (mem_size = gtk_object_get_data (GTK_OBJECT (adjustment), "mem_size")))
-    return;
-
-  divided_mem_size = (int) gtk_object_get_data (GTK_OBJECT (adjustment),
-						"divided_mem_size");
-  mem_size_unit = (int) gtk_object_get_data (GTK_OBJECT (adjustment),
-					     "mem_size_unit");
-
-  if (new_unit != mem_size_unit)
-    {
-      divided_mem_size = *mem_size / new_unit;
-      mem_size_unit = new_unit;
-
-      gtk_signal_handler_block_by_data (GTK_OBJECT (adjustment), mem_size);
-      gtk_adjustment_set_value (GTK_ADJUSTMENT (adjustment), divided_mem_size);
-      gtk_signal_handler_unblock_by_data (GTK_OBJECT (adjustment), mem_size);
-    }
-
-  gtk_object_set_data (GTK_OBJECT (adjustment), "divided_mem_size",
-		       (gpointer) divided_mem_size);
-  gtk_object_set_data (GTK_OBJECT (adjustment), "mem_size_unit",
-		       (gpointer) mem_size_unit);
-}
-
 static void
 file_prefs_string_callback (GtkWidget *widget,
 			    gpointer   data)
@@ -1043,6 +1007,27 @@ file_prefs_string_callback (GtkWidget *widget,
   file_prefs_strset (val, gtk_entry_get_text (GTK_ENTRY (widget)));
 }
 
+static void
+file_prefs_text_callback (GtkWidget *widget,
+			  gpointer   data)
+{
+  gchar **val;
+  gchar *text;
+  
+  val = data;
+
+  text = gtk_editable_get_chars (GTK_EDITABLE (widget), 0, -1);
+  if (strlen (text) > MAX_COMMENT_LENGTH)
+    {
+      g_message (_("The default comment is limited to %d characters."), 
+		 MAX_COMMENT_LENGTH);
+      gtk_editable_delete_text (GTK_EDITABLE (widget), MAX_COMMENT_LENGTH, -1);
+      g_free (text);
+    }
+  else
+    file_prefs_strset (val, text);
+}
+
 static void
 file_prefs_filename_callback (GtkWidget *widget,
 			      gpointer   data)
@@ -1081,7 +1066,7 @@ static void
 file_prefs_default_size_callback (GtkWidget *widget,
 				  gpointer   data)
 {
-  default_width = 
+  default_width =
     (gint) (gimp_size_entry_get_refval (GIMP_SIZE_ENTRY (widget), 0) + 0.5);
   default_height =
     (gint) (gimp_size_entry_get_refval (GIMP_SIZE_ENTRY (widget), 1) + 0.5);
@@ -1315,7 +1300,7 @@ file_prefs_help_func (gchar *help_data)
   event_box = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), page_num);
 
   help_data = gtk_object_get_data (GTK_OBJECT (event_box), "gimp_help_data");
-  gimp_help (help_data);
+  gimp_standard_help_func (help_data);
 }
 
 /************************************************************************
@@ -1349,11 +1334,10 @@ file_pref_cmd_callback (GtkWidget *widget,
   GtkObject *adjustment;
   GtkWidget *sizeentry;
   GtkWidget *sizeentry2;
+  GtkWidget *text;
   GSList    *group;
 
   gint i;
-  gint divided_mem_size;
-  gint mem_size_unit;
   gchar *pixels_per_unit;
 
   if (prefs_dlg)
@@ -1368,10 +1352,10 @@ file_pref_cmd_callback (GtkWidget *widget,
        *  copy config vals to edit variables.
        */
       edit_stingy_memory_use         = stingy_memory_use;
+      edit_min_colors                = min_colors;
       edit_install_cmap              = install_cmap;
       edit_cycled_marching_ants      = cycled_marching_ants;
       edit_last_opened_size          = last_opened_size;
-      edit_num_processors            = num_processors;
       edit_show_indicators           = show_indicators;
       edit_nav_window_per_display    = nav_window_per_display;
       edit_info_window_follows_mouse = info_window_follows_mouse;
@@ -1428,15 +1412,19 @@ file_pref_cmd_callback (GtkWidget *widget,
   old_trust_dirty_flag         = trust_dirty_flag;
   old_use_help                 = use_help;
   old_help_browser             = help_browser;
+  old_cursor_mode              = cursor_mode;
+  old_default_threshold        = default_threshold;
+  old_num_processors           = num_processors;
 
   file_prefs_strset (&old_image_title_format, image_title_format);	
+  file_prefs_strset (&old_default_comment, default_comment);	
 
   /*  values which will need a restart  */
   old_stingy_memory_use         = edit_stingy_memory_use;
+  old_min_colors                = edit_min_colors;
   old_install_cmap              = edit_install_cmap;
   old_cycled_marching_ants      = edit_cycled_marching_ants;
   old_last_opened_size          = edit_last_opened_size;
-  old_num_processors            = edit_num_processors;
   old_show_indicators           = edit_show_indicators;
   old_nav_window_per_display    = edit_nav_window_per_display;
   old_info_window_follows_mouse = edit_info_window_follows_mouse;
@@ -1642,50 +1630,47 @@ file_pref_cmd_callback (GtkWidget *widget,
 			     _("Default Image Type:"), 1.0, 0.5,
 			     optionmenu, 1, TRUE);
 
-  /*  The maximum size of a new image  */
-  mem_size_unit = 1;
-  for (i = 0; i < 3; i++)
-    {
-      if (max_new_image_size % (mem_size_unit * 1024) != 0)
-	break;
-      mem_size_unit *= 1024;
-    }
-  divided_mem_size = max_new_image_size / mem_size_unit;
-
-  hbox = gtk_hbox_new (FALSE, 2);
-  spinbutton =
-    gimp_spin_button_new (&adjustment, divided_mem_size,
-			  0.0, (4069.0 * 1024 * 1024), 1.0, 16.0, 0.0,
-			  1.0, 0.0);
+  /*  The maximum size of a new image  */  
+  adjustment = gtk_adjustment_new (max_new_image_size, 
+				   0, (4069.0 * 1024 * 1024 - 1), 
+				   1.0, 1.0, 0.0);
+  hbox = gimp_mem_size_entry_new (GTK_ADJUSTMENT (adjustment));
   gtk_signal_connect (GTK_OBJECT (adjustment), "value_changed",
-		      GTK_SIGNAL_FUNC (file_prefs_mem_size_callback),
+		      GTK_SIGNAL_FUNC (gimp_uint_adjustment_update),
 		      &max_new_image_size);
-  gtk_box_pack_start (GTK_BOX (hbox), spinbutton, FALSE, FALSE, 0);
-  gtk_widget_show (spinbutton);
-
-  /* for the mem_size_unit callback  */
-  gtk_object_set_data (GTK_OBJECT (adjustment), "mem_size",
-		       &max_new_image_size);
-  gtk_object_set_data (GTK_OBJECT (adjustment), "divided_mem_size",
-		       (gpointer) divided_mem_size);
-  gtk_object_set_data (GTK_OBJECT (adjustment), "mem_size_unit",
-		       (gpointer) mem_size_unit);
-
-  optionmenu =
-    gimp_option_menu_new2 (FALSE, file_prefs_mem_size_unit_callback,
-			   adjustment, (gpointer) mem_size_unit,
-
-			   _("Bytes"),     (gpointer) 1, NULL,
-			   _("KiloBytes"), (gpointer) 1024, NULL,
-			   _("MegaBytes"), (gpointer) (1024 * 1024), NULL,
-
-			   NULL);
-  gtk_box_pack_start (GTK_BOX (hbox), optionmenu, FALSE, FALSE, 0);
-  gtk_widget_show (optionmenu);
   gimp_table_attach_aligned (GTK_TABLE (table), 0, 1,
 			     _("Maximum Image Size:"), 1.0, 0.5,
 			     hbox, 1, TRUE);
 
+  /* Default Comment page */
+  vbox = file_prefs_notebook_append_page (GTK_NOTEBOOK (notebook),
+					  _("Default Comment"),
+					  GTK_CTREE (ctree),
+					  _("Default Comment"),
+					  "dialogs/preferences/default_comment.html",
+					  top_insert,
+					  &child_insert,
+					  page_index);
+  gtk_widget_show (vbox);
+  page_index++;
+
+  frame = gtk_frame_new (_("Comment Used for New Images"));
+  gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
+  gtk_widget_show (frame);
+ 
+  hbox = gtk_hbox_new (FALSE, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (hbox), 2);
+  gtk_container_add (GTK_CONTAINER (frame), hbox);
+  gtk_widget_show (hbox);
+
+  text = gtk_text_new (NULL, NULL);
+  gtk_text_set_editable (GTK_TEXT (text), TRUE);
+  gtk_text_insert (GTK_TEXT (text), NULL, NULL, NULL, default_comment, -1);
+  gtk_signal_connect (GTK_OBJECT (text), "changed",
+		      GTK_SIGNAL_FUNC (file_prefs_text_callback),
+		      &default_comment);
+  gtk_container_add (GTK_CONTAINER (hbox), text);
+  gtk_widget_show (text);
 
   /* Display page */
   vbox = file_prefs_notebook_append_page (GTK_NOTEBOOK (notebook),
@@ -1748,6 +1733,25 @@ file_pref_cmd_callback (GtkWidget *widget,
   if (g_visual->depth != 8)
     gtk_widget_set_sensitive (GTK_WIDGET (vbox2->parent), FALSE);
 
+  table = gtk_table_new (1, 2, FALSE);
+  gtk_container_set_border_width (GTK_CONTAINER (table), 2);
+  gtk_table_set_row_spacings (GTK_TABLE (table), 2);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+  gtk_box_pack_start (GTK_BOX (vbox2), table, FALSE, FALSE, 0);
+  gtk_widget_show (table);
+
+  spinbutton =
+    gimp_spin_button_new (&adjustment, edit_min_colors,
+			  27.0,
+			  gtk_check_version (1, 2, 8) ? 216.0 : 256.0,
+			  1.0, 8.0, 0.0, 1.0, 0.0);
+  gtk_signal_connect (GTK_OBJECT (adjustment), "value_changed",
+		      GTK_SIGNAL_FUNC (gimp_int_adjustment_update),
+		      &edit_min_colors);
+  gimp_table_attach_aligned (GTK_TABLE (table), 0, 0,
+			     _("Minimum Number of Colors:"), 1.0, 0.5,
+			     spinbutton, 1, TRUE);
+
   button = gtk_check_button_new_with_label(_("Install Colormap"));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button),
 				edit_install_cmap);
@@ -2056,6 +2060,28 @@ file_pref_cmd_callback (GtkWidget *widget,
 		      &no_cursor_updating);
   gtk_widget_show (button);
 
+  table = gtk_table_new (1, 2, FALSE);
+  gtk_container_set_border_width (GTK_CONTAINER (table), 2);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+  gtk_box_pack_start (GTK_BOX (vbox2), table, FALSE, FALSE, 0);
+  gtk_widget_show (table);
+
+  optionmenu =
+    gimp_option_menu_new2 (FALSE, file_prefs_toggle_callback,
+			   &cursor_mode, (gpointer) cursor_mode,
+
+			   _("Tool Icon"),
+			   (gpointer) CURSOR_MODE_TOOL_ICON, NULL,
+			   _("Tool Icon with Crosshair"),
+			   (gpointer) CURSOR_MODE_TOOL_CROSSHAIR, NULL,
+			   _("Crosshair only"),
+			   (gpointer) CURSOR_MODE_CROSSHAIR, NULL,
+
+			   NULL);
+  gimp_table_attach_aligned (GTK_TABLE (table), 0, 0,
+			     _("Cursor Mode:"), 1.0, 0.5,
+			     optionmenu, 1, TRUE);
+
 
   /* Interface / Tool Options */
   vbox = file_prefs_notebook_append_page (GTK_NOTEBOOK (notebook),
@@ -2081,6 +2107,28 @@ file_pref_cmd_callback (GtkWidget *widget,
 		      &global_paint_options);
   gtk_widget_show (button);
 
+  vbox2 = file_prefs_frame_new (_("Finding Contiguous Regions"),
+				GTK_BOX (vbox));
+
+  table = gtk_table_new (1, 2, FALSE);
+  gtk_container_set_border_width (GTK_CONTAINER (table), 2);
+  gtk_table_set_row_spacings (GTK_TABLE (table), 2);
+  gtk_table_set_col_spacings (GTK_TABLE (table), 4);
+  gtk_box_pack_start (GTK_BOX (vbox2), table, FALSE, FALSE, 0);
+  gtk_widget_show (table);
+
+  /*  Default threshold  */
+  spinbutton =
+    gimp_spin_button_new (&adjustment,
+			  default_threshold, 0.0, 255.0,
+			  1.0, 5.0, 0.0, 1.0, 0.0);
+  gtk_signal_connect (GTK_OBJECT (adjustment), "value_changed",
+		      GTK_SIGNAL_FUNC (gimp_int_adjustment_update),
+		      &default_threshold);
+  gimp_table_attach_aligned (GTK_TABLE (table), 0, 0,
+			     _("Default Threshold:"), 1.0, 0.5,
+			     spinbutton, 1, TRUE);
+
   /* Expand the "Interface" branch */
   gtk_ctree_expand (GTK_CTREE (ctree), top_insert);
 
@@ -2131,56 +2179,24 @@ file_pref_cmd_callback (GtkWidget *widget,
 			     spinbutton, 1, TRUE);
 
   /*  The tile cache size  */
-  mem_size_unit = 1;
-  for (i = 0; i < 3; i++)
-    {
-      if (edit_tile_cache_size % (mem_size_unit * 1024) != 0)
-	break;
-      mem_size_unit *= 1024;
-    }
-  divided_mem_size = edit_tile_cache_size / mem_size_unit;
-
-  hbox = gtk_hbox_new (FALSE, 2);
-  spinbutton =
-    gimp_spin_button_new (&adjustment, divided_mem_size,
-			  0.0, (4069.0 * 1024 * 1024), 1.0, 16.0, 0.0,
-			  1.0, 0.0);
+  adjustment = gtk_adjustment_new (edit_tile_cache_size, 
+				   0, (4069.0 * 1024 * 1024 - 1), 
+				   1.0, 1.0, 0.0);
+  hbox = gimp_mem_size_entry_new (GTK_ADJUSTMENT (adjustment));
   gtk_signal_connect (GTK_OBJECT (adjustment), "value_changed",
-		      GTK_SIGNAL_FUNC (file_prefs_mem_size_callback),
+		      GTK_SIGNAL_FUNC (gimp_uint_adjustment_update),
 		      &edit_tile_cache_size);
-  gtk_box_pack_start (GTK_BOX (hbox), spinbutton, FALSE, FALSE, 0);
-  gtk_widget_show (spinbutton);
-
-  /* for the mem_size_unit callback  */
-  gtk_object_set_data (GTK_OBJECT (adjustment), "mem_size",
-		       &edit_tile_cache_size);
-  gtk_object_set_data (GTK_OBJECT (adjustment), "divided_mem_size",
-		       (gpointer) divided_mem_size);
-  gtk_object_set_data (GTK_OBJECT (adjustment), "mem_size_unit",
-		       (gpointer) mem_size_unit);
-
-  optionmenu =
-    gimp_option_menu_new2 (FALSE, file_prefs_mem_size_unit_callback,
-			   adjustment, (gpointer) mem_size_unit,
-
-			   _("Bytes"),     (gpointer) 1, NULL,
-			   _("KiloBytes"), (gpointer) 1024, NULL, 
-			   _("MegaBytes"), (gpointer) (1024 * 1024), NULL,
-
-			   NULL);
-  gtk_box_pack_start (GTK_BOX (hbox), optionmenu, FALSE, FALSE, 0);
-  gtk_widget_show (optionmenu);
   gimp_table_attach_aligned (GTK_TABLE (table), 0, 1,
 			     _("Tile Cache Size:"), 1.0, 0.5,
 			     hbox, 1, TRUE);
 
 #ifdef ENABLE_MP
   spinbutton =
-    gimp_spin_button_new (&adjustment, edit_num_processors,
+    gimp_spin_button_new (&adjustment, num_processors,
 			  1, 30, 1.0, 2.0, 0.0, 1.0, 0.0);
   gtk_signal_connect (GTK_OBJECT (adjustment), "value_changed",
 		      GTK_SIGNAL_FUNC (gimp_int_adjustment_update),
-		      &edit_num_processors);
+		      &num_processors);
   gimp_table_attach_aligned (GTK_TABLE (table), 0, 2,
 			     _("Number of Processors to Use:"), 1.0, 0.5,
 			     spinbutton, 1, TRUE);
@@ -2283,6 +2299,7 @@ file_pref_cmd_callback (GtkWidget *widget,
   gtk_widget_show (hbox);
       
   button = gtk_button_new_with_label (_("Clear Saved Window Positions Now"));
+  gtk_misc_set_padding (GTK_MISC (GTK_BIN (button)->child), 2, 0);
   gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
   gtk_signal_connect (GTK_OBJECT (button), "clicked",
 		      GTK_SIGNAL_FUNC (file_prefs_clear_session_info_callback),
@@ -2324,14 +2341,15 @@ file_pref_cmd_callback (GtkWidget *widget,
   vbox2 = file_prefs_frame_new (_("Get Monitor Resolution"), GTK_BOX (vbox));
 
   {
-    gdouble xres, yres;
-    gchar   buf[80];
+    gdouble  xres, yres;
+    gchar   *str;
 
     gdisplay_xserver_resolution (&xres, &yres);
 
-    g_snprintf (buf, sizeof (buf), _("(Currently %d x %d dpi)"),
-		(int) (xres + 0.5), (int) (yres + 0.5));
-    label = gtk_label_new (buf);
+    str = g_strdup_printf (_("(Currently %d x %d dpi)"),
+			   ROUND (xres), ROUND (yres));
+    label = gtk_label_new (str);
+    g_free (str);
   }
 
   abox = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
@@ -2380,7 +2398,7 @@ file_pref_cmd_callback (GtkWidget *widget,
   gtk_widget_set_sensitive (sizeentry, !using_xserver_resolution);
 
   group = NULL;
-  button = gtk_radio_button_new_with_label (group, _("From X Server"));
+  button = gtk_radio_button_new_with_label (group, _("From windowing system"));
   group = gtk_radio_button_group (GTK_RADIO_BUTTON (button));
   gtk_signal_connect (GTK_OBJECT (button), "toggled",
 		      GTK_SIGNAL_FUNC (file_prefs_res_source_callback),
