@@ -17,7 +17,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* $Id: pnm.c,v 1.19 2000/02/10 23:17:22 neo Exp $ */
+/* $Id: pnm.c,v 1.24 2000/08/24 14:17:32 neo Exp $ */
 
 /*
  * The pnm reading and writing code was written from scratch by Erik Nygren
@@ -47,6 +47,7 @@
 
 #include "libgimp/stdplugins-intl.h"
 
+
 #ifdef G_OS_WIN32
 #include <io.h>
 #endif
@@ -78,7 +79,7 @@ typedef struct _PNMInfo
   gint       asciibody;		/* 1 if ascii body, 0 if raw body */
   jmp_buf    jmpbuf;		/* Where to jump to on an error loading */
   /* Routine to use to load the pnm body */
-  void    (* loader) (PNMScanner *, struct _PNMInfo *, GPixelRgn *);
+  void    (* loader) (PNMScanner *, struct _PNMInfo *, GimpPixelRgn *);
 } PNMInfo;
 
 /* Contains the information needed to write out PNM rows */
@@ -117,28 +118,27 @@ typedef struct
 static void   query      (void);
 static void   run        (gchar   *name,
                           gint     nparams,
-                          GParam  *param,
+                          GimpParam  *param,
                           gint    *nreturn_vals,
-                          GParam **return_vals);
+                          GimpParam **return_vals);
 static gint32 load_image (gchar  *filename);
 static gint   save_image (gchar  *filename,
 			  gint32  image_ID,
 			  gint32  drawable_ID);
 
-static void   init_gtk                 (void);
 static gint   save_dialog              (void);
 static void   save_ok_callback         (GtkWidget *widget,
 					gpointer   data);
 
 static void   pnm_load_ascii           (PNMScanner *scan,
 					PNMInfo    *info,
-					GPixelRgn  *pixel_rgn);
+					GimpPixelRgn  *pixel_rgn);
 static void   pnm_load_raw             (PNMScanner *scan,
 					PNMInfo    *info,
-					GPixelRgn  *pixel_rgn);
+					GimpPixelRgn  *pixel_rgn);
 static void   pnm_load_rawpbm          (PNMScanner *scan,
 					PNMInfo    *info,
-					GPixelRgn  *pixel_rgn);
+					GimpPixelRgn  *pixel_rgn);
 
 static void   pnmsaverow_ascii         (PNMRowInfo *ri,
 					guchar     *data);
@@ -157,6 +157,8 @@ static void   pnmscanner_eatwhitespace (PNMScanner *s);
 static void   pnmscanner_gettoken      (PNMScanner *s,
 					gchar      *buf,
 					gint        bufsize);
+static void   pnmscanner_getsmalltoken (PNMScanner *s,
+					gchar      *buf);
 
 static PNMScanner * pnmscanner_create  (gint        fd);
 
@@ -167,7 +169,7 @@ static PNMScanner * pnmscanner_create  (gint        fd);
 /* Checks for a fatal error */
 #define CHECK_FOR_ERROR(predicate, jmpbuf, errmsg) \
         if ((predicate)) \
-        { /*gimp_message((errmsg));*/ longjmp((jmpbuf),1); }
+        { g_message ((errmsg)); longjmp((jmpbuf),1); }
 
 static struct struct_pnm_types
 {
@@ -175,7 +177,7 @@ static struct struct_pnm_types
   gint    np;
   gint    asciibody;
   gint    maxval;
-  void (* loader) (PNMScanner *, struct _PNMInfo *, GPixelRgn *pixel_rgn);
+  void (* loader) (PNMScanner *, struct _PNMInfo *, GimpPixelRgn *pixel_rgn);
 } pnm_types[] =
 {
   { '1', 0, 1,   1, pnm_load_ascii },  /* ASCII PBM */
@@ -187,7 +189,7 @@ static struct struct_pnm_types
   {  0 , 0, 0,   0, NULL}
 };
 
-GPlugInInfo PLUG_IN_INFO =
+GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,  /* init_proc  */
   NULL,  /* quit_proc  */
@@ -211,33 +213,31 @@ MAIN ()
 static void
 query (void)
 {
-  static GParamDef load_args[] =
+  static GimpParamDef load_args[] =
   {
-    { PARAM_INT32, "run_mode", "Interactive, non-interactive" },
-    { PARAM_STRING, "filename", "The name of the file to load" },
-    { PARAM_STRING, "raw_filename", "The name of the file to load" },
+    { GIMP_PDB_INT32, "run_mode", "Interactive, non-interactive" },
+    { GIMP_PDB_STRING, "filename", "The name of the file to load" },
+    { GIMP_PDB_STRING, "raw_filename", "The name of the file to load" }
   };
-  static GParamDef load_return_vals[] =
+  static GimpParamDef load_return_vals[] =
   {
-    { PARAM_IMAGE, "image", "Output image" },
+    { GIMP_PDB_IMAGE, "image", "Output image" }
   };
   static gint nload_args = sizeof (load_args) / sizeof (load_args[0]);
   static gint nload_return_vals = (sizeof (load_return_vals) /
 				   sizeof (load_return_vals[0]));
 
-  static GParamDef save_args[] =
+  static GimpParamDef save_args[] =
   {
-    { PARAM_INT32,    "run_mode",     "Interactive, non-interactive" },
-    { PARAM_IMAGE,    "image",        "Input image" },
-    { PARAM_DRAWABLE, "drawable",     "Drawable to save" },
-    { PARAM_STRING,   "filename",     "The name of the file to save the image in" },
-    { PARAM_STRING,   "raw_filename", "The name of the file to save the image in" },
-    { PARAM_INT32,    "raw",          "Specify non-zero for raw output, zero for ascii output" }
+    { GIMP_PDB_INT32,    "run_mode",     "Interactive, non-interactive" },
+    { GIMP_PDB_IMAGE,    "image",        "Input image" },
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save" },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
+    { GIMP_PDB_STRING,   "raw_filename", "The name of the file to save the image in" },
+    { GIMP_PDB_INT32,    "raw",          "Specify non-zero for raw output, zero for ascii output" }
   };
   static gint nsave_args = sizeof (save_args) / sizeof (save_args[0]);
 
-  INIT_I18N();
-
   gimp_install_procedure ("file_pnm_load",
                           "loads files of the pnm file format",
                           "FIXME: write help for pnm_load",
@@ -246,7 +246,7 @@ query (void)
                           "1996",
                           "<Load>/PNM",
 			  NULL,
-                          PROC_PLUG_IN,
+                          GIMP_PLUGIN,
                           nload_args, nload_return_vals,
                           load_args, load_return_vals);
 
@@ -258,7 +258,7 @@ query (void)
                           "1996",
                           "<Save>/PNM",
 			  "RGB, GRAY, INDEXED",
-                          PROC_PLUG_IN,
+                          GIMP_PLUGIN,
                           nsave_args, 0,
                           save_args, NULL);
 
@@ -275,25 +275,25 @@ query (void)
 static void
 run (gchar   *name,
      gint     nparams,
-     GParam  *param,
+     GimpParam  *param,
      gint    *nreturn_vals,
-     GParam **return_vals)
+     GimpParam **return_vals)
 {
-  static GParam values[2];
-  GRunModeType  run_mode;
-  GStatusType   status = STATUS_SUCCESS;
+  static GimpParam values[2];
+  GimpRunModeType  run_mode;
+  GimpPDBStatusType   status = GIMP_PDB_SUCCESS;
   gint32        image_ID;
   gint32        drawable_ID;
-  GimpExportReturnType export = EXPORT_CANCEL;
+  GimpExportReturnType export = GIMP_EXPORT_CANCEL;
 
   run_mode = param[0].data.d_int32;
 
   *nreturn_vals = 1;
   *return_vals  = values;
-  values[0].type          = PARAM_STATUS;
-  values[0].data.d_status = STATUS_EXECUTION_ERROR;
+  values[0].type          = GIMP_PDB_STATUS;
+  values[0].data.d_status = GIMP_PDB_EXECUTION_ERROR;
 
-  if (run_mode == RUN_NONINTERACTIVE)
+  if (run_mode == GIMP_RUN_NONINTERACTIVE)
     {
       INIT_I18N();
     }
@@ -309,12 +309,12 @@ run (gchar   *name,
       if (image_ID != -1)
 	{
 	  *nreturn_vals = 2;
-	  values[1].type         = PARAM_IMAGE;
+	  values[1].type         = GIMP_PDB_IMAGE;
 	  values[1].data.d_image = image_ID;
 	}
       else
 	{
-	  status = STATUS_EXECUTION_ERROR;
+	  status = GIMP_PDB_EXECUTION_ERROR;
 	}
     }
   else if (strcmp (name, "file_pnm_save") == 0)
@@ -325,16 +325,16 @@ run (gchar   *name,
       /*  eventually export the image */ 
       switch (run_mode)
 	{
-	case RUN_INTERACTIVE:
-	case RUN_WITH_LAST_VALS:
-	  init_gtk ();
+	case GIMP_RUN_INTERACTIVE:
+	case GIMP_RUN_WITH_LAST_VALS:
+	  gimp_ui_init ("pnm", FALSE);
 	  export = gimp_export_image (&image_ID, &drawable_ID, "PNM", 
-				      (CAN_HANDLE_RGB |
-				       CAN_HANDLE_GRAY |
-				       CAN_HANDLE_INDEXED));
-	  if (export == EXPORT_CANCEL)
+				      (GIMP_EXPORT_CAN_HANDLE_RGB |
+				       GIMP_EXPORT_CAN_HANDLE_GRAY |
+				       GIMP_EXPORT_CAN_HANDLE_INDEXED));
+	  if (export == GIMP_EXPORT_CANCEL)
 	    {
-	      values[0].data.d_status = STATUS_CANCEL;
+	      values[0].data.d_status = GIMP_PDB_CANCEL;
 	      return;
 	    }
 	break;
@@ -344,27 +344,27 @@ run (gchar   *name,
 
       switch (run_mode)
 	{
-	case RUN_INTERACTIVE:
+	case GIMP_RUN_INTERACTIVE:
 	  /*  Possibly retrieve data  */
 	  gimp_get_data ("file_pnm_save", &psvals);
 
 	  /*  First acquire information with a dialog  */
 	  if (! save_dialog ())
-	    status = STATUS_CANCEL;
+	    status = GIMP_PDB_CANCEL;
 	  break;
 
-	case RUN_NONINTERACTIVE:
+	case GIMP_RUN_NONINTERACTIVE:
 	  /*  Make sure all the arguments are there!  */
 	  if (nparams != 6)
 	    {
-	      status = STATUS_CALLING_ERROR;
+	      status = GIMP_PDB_CALLING_ERROR;
 	    }
 	  else
 	    {
 	      psvals.raw = (param[5].data.d_int32) ? TRUE : FALSE;
 	    }
 
-	case RUN_WITH_LAST_VALS:
+	case GIMP_RUN_WITH_LAST_VALS:
 	  /*  Possibly retrieve data  */
 	  gimp_get_data ("file_pnm_save", &psvals);
 	  break;
@@ -373,7 +373,7 @@ run (gchar   *name,
 	  break;
 	}
 
-      if (status == STATUS_SUCCESS)
+      if (status == GIMP_PDB_SUCCESS)
 	{
 	  if (save_image (param[3].data.d_string, image_ID, drawable_ID))
 	    {
@@ -382,16 +382,16 @@ run (gchar   *name,
 	    }
 	  else
 	    {
-	      status = STATUS_EXECUTION_ERROR;
+	      status = GIMP_PDB_EXECUTION_ERROR;
 	    }
 	}
 
-      if (export == EXPORT_EXPORT)
+      if (export == GIMP_EXPORT_EXPORT)
 	gimp_image_delete (image_ID);
     }
   else
     {
-      status = STATUS_CALLING_ERROR;
+      status = GIMP_PDB_CALLING_ERROR;
     }
 
   values[0].data.d_status = status;
@@ -400,15 +400,15 @@ run (gchar   *name,
 static gint32
 load_image (gchar *filename)
 {
-  GPixelRgn pixel_rgn;
-  gint32 image_ID;
+  GimpPixelRgn pixel_rgn;
+  gint32 volatile image_ID = -1;
   gint32 layer_ID;
-  GDrawable *drawable;
+  GimpDrawable *drawable;
   int fd;			/* File descriptor */
   char *temp;
   char buf[BUFLEN];		/* buffer for random things like scanning */
   PNMInfo *pnminfo;
-  PNMScanner *scan;
+  PNMScanner * volatile scan;
   int ctr;
 
   temp = g_strdup_printf (_("Loading %s:"), filename);
@@ -420,7 +420,7 @@ load_image (gchar *filename)
 
   if (fd == -1)
     {
-      /*gimp_message("pnm filter: can't open file\n");*/
+      g_message (_("PNM: Can't open file %s."), filename);
       return -1;
     }
 
@@ -436,6 +436,8 @@ load_image (gchar *filename)
 	pnmscanner_destroy (scan);
       close (fd);
       g_free (pnminfo);
+      if (image_ID != -1)
+	gimp_image_delete (image_ID);
       return -1;
     }
 
@@ -445,9 +447,9 @@ load_image (gchar *filename)
   /* Get magic number */
   pnmscanner_gettoken (scan, buf, BUFLEN);
   CHECK_FOR_ERROR(pnmscanner_eof(scan), pnminfo->jmpbuf,
-		  "pnm filter: premature end of file\n");
+		  _("PNM: Premature end of file."));
   CHECK_FOR_ERROR((buf[0] != 'P' || buf[2]), pnminfo->jmpbuf,
-		  "pnm filter: %s is not a valid file\n");
+		  _("PNM: %s is not a valid file."));
 
   /* Look up magic number to see what type of PNM this is */
   for (ctr=0; pnm_types[ctr].name; ctr++)
@@ -460,47 +462,47 @@ load_image (gchar *filename)
       }
   if (!pnminfo->loader)
     {
-      /*gimp_message("pnm filter: file not in a supported format\n");*/
+      g_message (_("PNM: File not in a supported format."));
       longjmp(pnminfo->jmpbuf,1);
     }
 
   pnmscanner_gettoken(scan, buf, BUFLEN);
   CHECK_FOR_ERROR(pnmscanner_eof(scan), pnminfo->jmpbuf,
-		  "pnm filter: premature end of file\n");
+		  _("PNM: Premature end of file."));
   pnminfo->xres = isdigit(*buf)?atoi(buf):0;
   CHECK_FOR_ERROR(pnminfo->xres<=0, pnminfo->jmpbuf,
-		  "pnm filter: invalid xres while loading\n");
+		  _("PNM: Invalid X resolution."));
 
   pnmscanner_gettoken(scan, buf, BUFLEN);
   CHECK_FOR_ERROR(pnmscanner_eof(scan), pnminfo->jmpbuf,
-		  "pnm filter: premature end of file\n");
+		  _("PNM: Premature end of file."));
   pnminfo->yres = isdigit(*buf)?atoi(buf):0;
   CHECK_FOR_ERROR(pnminfo->yres<=0, pnminfo->jmpbuf,
-		  "pnm filter: invalid yres while loading\n");
+		  _("PNM: Invalid Y resolution."));
 
   if (pnminfo->np != 0)		/* pbm's don't have a maxval field */
     {
       pnmscanner_gettoken(scan, buf, BUFLEN);
       CHECK_FOR_ERROR(pnmscanner_eof(scan), pnminfo->jmpbuf,
-		      "pnm filter: premature end of file\n");
+		      _("PNM: Premature end of file."));
 
       pnminfo->maxval = isdigit(*buf)?atoi(buf):0;
       CHECK_FOR_ERROR(((pnminfo->maxval<=0)
 		       || (pnminfo->maxval>255 && !pnminfo->asciibody)),
 		      pnminfo->jmpbuf,
-		      "pnm filter: invalid maxval while loading\n");
+		      _("PNM: Invalid maximum value."));
     }
 
   /* Create a new image of the proper size and associate the filename with it.
    */
   image_ID = gimp_image_new (pnminfo->xres, pnminfo->yres,
-			     (pnminfo->np >= 3) ? RGB : GRAY);
+			     (pnminfo->np >= 3) ? GIMP_RGB : GIMP_GRAY);
   gimp_image_set_filename (image_ID, filename);
 
   layer_ID = gimp_layer_new (image_ID, _("Background"),
 			     pnminfo->xres, pnminfo->yres,
-			     (pnminfo->np >= 3) ? RGB_IMAGE : GRAY_IMAGE,
-			     100, NORMAL_MODE);
+			     (pnminfo->np >= 3) ? GIMP_RGB_IMAGE : GIMP_GRAY_IMAGE,
+			     100, GIMP_NORMAL_MODE);
   gimp_image_add_layer (image_ID, layer_ID, 0);
 
   drawable = gimp_drawable_get (layer_ID);
@@ -528,7 +530,7 @@ load_image (gchar *filename)
 static void
 pnm_load_ascii (PNMScanner *scan,
 		PNMInfo    *info,
-		GPixelRgn  *pixel_rgn)
+		GimpPixelRgn  *pixel_rgn)
 {
   unsigned char *data, *d;
   int            x, y, i, b;
@@ -557,8 +559,11 @@ pnm_load_ascii (PNMScanner *scan,
 	      {
 		/* Truncated files will just have all 0's at the end of the images */
 		CHECK_FOR_ERROR(pnmscanner_eof(scan), info->jmpbuf,
-				"pnm filter: premature end of file\n");
-		pnmscanner_gettoken(scan, buf, BUFLEN);
+				_("PNM: Premature end of file."));
+		if (info->np)
+		  pnmscanner_gettoken(scan, buf, BUFLEN);
+		else
+		  pnmscanner_getsmalltoken(scan, buf);
 		switch (info->maxval)
 		  {
 		  case 255:
@@ -587,7 +592,7 @@ pnm_load_ascii (PNMScanner *scan,
 static void
 pnm_load_raw (PNMScanner *scan,
 	      PNMInfo    *info,
-	      GPixelRgn  *pixel_rgn)
+	      GimpPixelRgn  *pixel_rgn)
 {
   unsigned char *data, *d;
   int            x, y, i;
@@ -610,7 +615,7 @@ pnm_load_raw (PNMScanner *scan,
 	  CHECK_FOR_ERROR((info->xres*info->np
 			   != read(fd, d, info->xres*info->np)),
 			  info->jmpbuf,
-			  "pnm filter: premature end of file\n");
+			  _("PNM: Premature end of file."));
 
 	  if (info->maxval != 255)	/* Normalize if needed */
 	    {
@@ -632,7 +637,7 @@ pnm_load_raw (PNMScanner *scan,
 static void
 pnm_load_rawpbm (PNMScanner *scan,
 		 PNMInfo    *info,
-		 GPixelRgn  *pixel_rgn)
+		 GimpPixelRgn  *pixel_rgn)
 {
   unsigned char *buf;
   unsigned char  curbyte;
@@ -658,7 +663,7 @@ pnm_load_rawpbm (PNMScanner *scan,
       for (i = 0; i < scanlines; i++)
 	{
 	  CHECK_FOR_ERROR((rowlen != read(fd, buf, rowlen)),
-			  info->jmpbuf, "pnm filter: error reading file\n");
+			  info->jmpbuf, _("PNM: Error reading file."));
 	  bufpos = 0;
 	  curbyte = buf[0];
 
@@ -748,9 +753,9 @@ save_image (gchar  *filename,
 	    gint32  image_ID,
 	    gint32  drawable_ID)
 {
-  GPixelRgn pixel_rgn;
-  GDrawable *drawable;
-  GDrawableType drawable_type;
+  GimpPixelRgn pixel_rgn;
+  GimpDrawable *drawable;
+  GimpImageType drawable_type;
   PNMRowInfo rowinfo;
   void (*saverow) (PNMRowInfo *, unsigned char *) = NULL;
   unsigned char red[256];
@@ -798,19 +803,19 @@ save_image (gchar  *filename,
   if (psvals.raw == FALSE)
     switch (drawable_type)
       {
-      case GRAY_IMAGE:
+      case GIMP_GRAY_IMAGE:
 	write(fd, "P2\n", 3);
 	np = 1;
 	rowbufsize = xres * 4;
 	saverow = pnmsaverow_ascii;
 	break;
-      case RGB_IMAGE:
+      case GIMP_RGB_IMAGE:
 	write(fd, "P3\n", 3);
 	np = 3;
 	rowbufsize = xres * 12;
 	saverow = pnmsaverow_ascii;
 	break;
-      case INDEXED_IMAGE:
+      case GIMP_INDEXED_IMAGE:
 	write(fd, "P3\n", 3);
 	np = 1;
 	rowbufsize = xres * 12;
@@ -823,19 +828,19 @@ save_image (gchar  *filename,
   else if (psvals.raw == TRUE)
     switch (drawable_type)
       {
-      case GRAY_IMAGE:
+      case GIMP_GRAY_IMAGE:
 	write(fd, "P5\n", 3);
 	np = 1;
 	rowbufsize = xres;
 	saverow = pnmsaverow_raw;
 	break;
-      case RGB_IMAGE:
+      case GIMP_RGB_IMAGE:
 	write(fd, "P6\n", 3);
 	np = 3;
 	rowbufsize = xres * 3;
 	saverow = pnmsaverow_raw;
 	break;
-      case INDEXED_IMAGE:
+      case GIMP_INDEXED_IMAGE:
 	write(fd, "P6\n", 3);
 	np = 1;
 	rowbufsize = xres * 3;
@@ -846,7 +851,7 @@ save_image (gchar  *filename,
 	return FALSE;
     }
 
-  if (drawable_type == INDEXED_IMAGE)
+  if (drawable_type == GIMP_INDEXED_IMAGE)
     {
       int i;
       guchar *cmap;
@@ -914,21 +919,6 @@ save_image (gchar  *filename,
   return TRUE;
 }
 
-
-static void 
-init_gtk (void)
-{
-  gchar **argv;
-  gint   argc;
-
-  argc    = 1;
-  argv    = g_new (gchar *, 1);
-  argv[0] = g_strdup ("pnm");
-
-  gtk_init (&argc, &argv);
-  gtk_rc_parse (gimp_gtkrc ());
-}
-
 static gint
 save_dialog (void)
 {
@@ -936,7 +926,7 @@ save_dialog (void)
   GtkWidget *frame;
 
   dlg = gimp_dialog_new (_("Save as PNM"), "pnm",
-			 gimp_plugin_help_func, "filters/pnm.html",
+			 gimp_standard_help_func, "filters/pnm.html",
 			 GTK_WIN_POS_MOUSE,
 			 FALSE, TRUE, FALSE,
 
@@ -1042,6 +1032,21 @@ pnmscanner_gettoken (PNMScanner *s,
   buf[ctr] = '\0';
 }
 
+/* pnmscanner_getsmalltoken ---
+ *    Gets the next char, eating any leading whitespace.
+ */
+static void
+pnmscanner_getsmalltoken (PNMScanner *s,
+			  gchar      *buf)
+{
+  pnmscanner_eatwhitespace(s);
+  if (!(s->eof) && !isspace(s->cur) && (s->cur != '#'))
+    {
+      *buf = s->cur;
+      pnmscanner_getchar(s);
+    }
+}
+
 /* pnmscanner_getchar ---
  *    Reads a character from the input stream
  */
