@@ -4,8 +4,13 @@
  * njl195@zepler.org.uk -- 18 May 1998
  * And it now gains support for tiles (and doubtless a zillion bugs)
  * njl195@zepler.org.uk -- 12 June 1999
+ * LZW patent fuss continues :(
+ * njl195@zepler.org.uk -- 20 April 2000
  * The code for this filter is based on "tifftopnm" and "pnmtotiff",
  *  2 programs that are a part of the netpbm package.
+ * khk@khk.net -- 13 May 2000
+ * Added support for ICCPROFILE tiff tag. If this tag is present in a 
+ * TIFF file, then a parasite is created and vice versa.
  */
 
 /*
@@ -42,6 +47,7 @@
 
 #include "libgimp/stdplugins-intl.h"
 
+
 typedef struct
 {
   gint  compression;
@@ -56,8 +62,8 @@ typedef struct
 typedef struct
 {
   gint32     ID;
-  GDrawable *drawable;
-  GPixelRgn  pixel_rgn;
+  GimpDrawable *drawable;
+  GimpPixelRgn  pixel_rgn;
   guchar    *pixels;
   guchar    *pixel;
 } channel_data;
@@ -67,9 +73,9 @@ typedef struct
 static void   query   (void);
 static void   run     (gchar   *name,
 		       gint     nparams,
-		       GParam  *param,
+		       GimpParam  *param,
 		       gint    *nreturn_vals,
-		       GParam **return_vals);
+		       GimpParam **return_vals);
 
 static gint32 load_image    (gchar        *filename);
 
@@ -133,7 +139,6 @@ static gint   save_image             (gchar     *filename,
 				      gint32     drawable,
 				      gint32     orig_image);
 
-static void   init_gtk               (void);
 static gint   save_dialog            (void);
 
 static void   save_ok_callback       (GtkWidget *widget,
@@ -143,7 +148,7 @@ static void   comment_entry_callback (GtkWidget *widget,
 
 #define DEFAULT_COMMENT "Created with The GIMP"
 
-GPlugInInfo PLUG_IN_INFO =
+GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,  /* init_proc  */
   NULL,  /* quit_proc  */
@@ -153,7 +158,7 @@ GPlugInInfo PLUG_IN_INFO =
 
 static TiffSaveVals tsvals =
 {
-  COMPRESSION_LZW,    /*  compression  */
+  COMPRESSION_NONE,    /*  compression  */
 };
 
 static TiffSaveInterface tsint =
@@ -168,42 +173,40 @@ MAIN ()
 static void
 query (void)
 {
-  static GParamDef load_args[] =
+  static GimpParamDef load_args[] =
   {
-    { PARAM_INT32, "run_mode", "Interactive, non-interactive" },
-    { PARAM_STRING, "filename", "The name of the file to load" },
-    { PARAM_STRING, "raw_filename", "The name of the file to load" },
+    { GIMP_PDB_INT32, "run_mode", "Interactive, non-interactive" },
+    { GIMP_PDB_STRING, "filename", "The name of the file to load" },
+    { GIMP_PDB_STRING, "raw_filename", "The name of the file to load" }
   };
-  static GParamDef load_return_vals[] =
+  static GimpParamDef load_return_vals[] =
   {
-    { PARAM_IMAGE, "image", "Output image" },
+    { GIMP_PDB_IMAGE, "image", "Output image" }
   };
   static gint nload_args = sizeof (load_args) / sizeof (load_args[0]);
   static gint nload_return_vals = (sizeof (load_return_vals) /
 				   sizeof (load_return_vals[0]));
 
-  static GParamDef save_args[] =
+  static GimpParamDef save_args[] =
   {
-    { PARAM_INT32, "run_mode", "Interactive, non-interactive" },
-    { PARAM_IMAGE, "image", "Input image" },
-    { PARAM_DRAWABLE, "drawable", "Drawable to save" },
-    { PARAM_STRING, "filename", "The name of the file to save the image in" },
-    { PARAM_STRING, "raw_filename", "The name of the file to save the image in" },
-    { PARAM_INT32, "compression", "Compression type: { NONE (0), LZW (1), PACKBITS (2)" },
+    { GIMP_PDB_INT32, "run_mode", "Interactive, non-interactive" },
+    { GIMP_PDB_IMAGE, "image", "Input image" },
+    { GIMP_PDB_DRAWABLE, "drawable", "Drawable to save" },
+    { GIMP_PDB_STRING, "filename", "The name of the file to save the image in" },
+    { GIMP_PDB_STRING, "raw_filename", "The name of the file to save the image in" },
+    { GIMP_PDB_INT32, "compression", "Compression type: { NONE (0), LZW (1), PACKBITS (2), DEFLATE (3), JPEG (4)" }
   };
   static gint nsave_args = sizeof (save_args) / sizeof (save_args[0]);
 
-  INIT_I18N();
-
   gimp_install_procedure ("file_tiff_load",
                           "loads files of the tiff file format",
                           "FIXME: write help for tiff_load",
                           "Spencer Kimball, Peter Mattis & Nick Lamb",
                           "Nick Lamb <njl195@zepler.org.uk>",
-                          "1995-1996,1998-1999",
+                          "1995-1996,1998-2000",
                           "<Load>/Tiff",
 			  NULL,
-                          PROC_PLUG_IN,
+                          GIMP_PLUGIN,
                           nload_args, nload_return_vals,
                           load_args, load_return_vals);
 
@@ -212,10 +215,10 @@ query (void)
                           "FIXME: write help for tiff_save",
                           "Spencer Kimball & Peter Mattis",
                           "Spencer Kimball & Peter Mattis",
-                          "1995-1996",
+                          "1995-1996,2000",
                           "<Save>/Tiff",
 			  "RGB*, GRAY*, INDEXED",
-                          PROC_PLUG_IN,
+                          GIMP_PLUGIN,
                           nsave_args, 0,
                           save_args, NULL);
 
@@ -231,27 +234,27 @@ query (void)
 static void
 run (gchar   *name,
      gint     nparams,
-     GParam  *param,
+     GimpParam  *param,
      gint    *nreturn_vals,
-     GParam **return_vals)
+     GimpParam **return_vals)
 {
-  static GParam values[2];
-  GRunModeType  run_mode;
-  GStatusType   status = STATUS_SUCCESS;
+  static GimpParam values[2];
+  GimpRunModeType  run_mode;
+  GimpPDBStatusType   status = GIMP_PDB_SUCCESS;
 #ifdef GIMP_HAVE_PARASITES
-  Parasite     *parasite;
+  GimpParasite *parasite;
 #endif /* GIMP_HAVE_PARASITES */
   gint32        image;
   gint32        drawable;
   gint32        orig_image;
-  GimpExportReturnType export = EXPORT_CANCEL;
+  GimpExportReturnType export = GIMP_EXPORT_CANCEL;
 
   run_mode = param[0].data.d_int32;
 
   *nreturn_vals = 1;
   *return_vals  = values;
-  values[0].type          = PARAM_STATUS;
-  values[0].data.d_status = STATUS_EXECUTION_ERROR;
+  values[0].type          = GIMP_PDB_STATUS;
+  values[0].data.d_status = GIMP_PDB_EXECUTION_ERROR;
 
   if (strcmp (name, "file_tiff_load") == 0)
     {
@@ -261,12 +264,12 @@ run (gchar   *name,
       if (image != -1)
 	{
 	  *nreturn_vals = 2;
-	  values[1].type         = PARAM_IMAGE;
+	  values[1].type         = GIMP_PDB_IMAGE;
 	  values[1].data.d_image = image;
 	}
       else
 	{
-	  status = STATUS_EXECUTION_ERROR;
+	  status = GIMP_PDB_EXECUTION_ERROR;
 	}
     }
   else if (strcmp (name, "file_tiff_save") == 0)
@@ -280,18 +283,18 @@ run (gchar   *name,
       /*  eventually export the image */ 
       switch (run_mode)
 	{
-	case RUN_INTERACTIVE:
-	case RUN_WITH_LAST_VALS:
+	case GIMP_RUN_INTERACTIVE:
+	case GIMP_RUN_WITH_LAST_VALS:
 	  INIT_I18N_UI();
-	  init_gtk ();
+	  gimp_ui_init ("tiff", FALSE);
 	  export = gimp_export_image (&image, &drawable, "TIFF", 
-				      (CAN_HANDLE_RGB |
-				       CAN_HANDLE_GRAY |
-				       CAN_HANDLE_INDEXED | 
-				       CAN_HANDLE_ALPHA));
-	  if (export == EXPORT_CANCEL)
+				      (GIMP_EXPORT_CAN_HANDLE_RGB |
+				       GIMP_EXPORT_CAN_HANDLE_GRAY |
+				       GIMP_EXPORT_CAN_HANDLE_INDEXED | 
+				       GIMP_EXPORT_CAN_HANDLE_ALPHA ));
+	  if (export == GIMP_EXPORT_CANCEL)
 	    {
-	      values[0].data.d_status = STATUS_CANCEL;
+	      values[0].data.d_status = GIMP_PDB_CANCEL;
 	      return;
 	    }
 	  break;
@@ -303,7 +306,7 @@ run (gchar   *name,
       parasite = gimp_image_parasite_find (orig_image, "gimp-comment");
       if (parasite)
         image_comment = g_strdup (parasite->data);
-      parasite_free (parasite);
+      gimp_parasite_free (parasite);
 #endif /* GIMP_HAVE_PARASITES */
 
       if (!image_comment)
@@ -311,7 +314,7 @@ run (gchar   *name,
 
       switch (run_mode)
 	{
-	case RUN_INTERACTIVE:
+	case GIMP_RUN_INTERACTIVE:
 	  /*  Possibly retrieve data  */
 	  gimp_get_data ("file_tiff_save", &tsvals);
 
@@ -322,20 +325,20 @@ run (gchar   *name,
 	      tsvals.compression =
 		((TiffSaveVals *) parasite->data)->compression;
 	    }
-	  parasite_free (parasite);
+	  gimp_parasite_free (parasite);
 #endif /* GIMP_HAVE_PARASITES */
 
 	  /*  First acquire information with a dialog  */
 	  if (! save_dialog ())
-	    status = STATUS_CANCEL;
+	    status = GIMP_PDB_CANCEL;
 	  break;
 
-	case RUN_NONINTERACTIVE:
+	case GIMP_RUN_NONINTERACTIVE:
 	  INIT_I18N();
 	  /*  Make sure all the arguments are there!  */
 	  if (nparams != 6)
 	    {
-	      status = STATUS_CALLING_ERROR;
+	      status = GIMP_PDB_CALLING_ERROR;
 	    }
 	  else
 	    {
@@ -344,11 +347,14 @@ run (gchar   *name,
 		case 0: tsvals.compression = COMPRESSION_NONE;     break;
 		case 1: tsvals.compression = COMPRESSION_LZW;      break;
 		case 2: tsvals.compression = COMPRESSION_PACKBITS; break;
-		default: status = STATUS_CALLING_ERROR; break;
+		case 3: tsvals.compression = COMPRESSION_DEFLATE;  break;
+		case 4: tsvals.compression = COMPRESSION_JPEG;  break;
+		default: status = GIMP_PDB_CALLING_ERROR; break;
 		}
 	    }
+	  break;
 
-	case RUN_WITH_LAST_VALS:
+	case GIMP_RUN_WITH_LAST_VALS:
 	  /*  Possibly retrieve data  */
 	  gimp_get_data ("file_tiff_save", &tsvals);
 
@@ -359,7 +365,7 @@ run (gchar   *name,
 	      tsvals.compression =
 		((TiffSaveVals *) parasite->data)->compression;
 	    }
-	  parasite_free (parasite);
+	  gimp_parasite_free (parasite);
 #endif /* GIMP_HAVE_PARASITES */
 	  break;
 
@@ -367,7 +373,7 @@ run (gchar   *name,
 	  break;
 	}
 
-      if (status == STATUS_SUCCESS)
+      if (status == GIMP_PDB_SUCCESS)
 	{
 	  if (save_image (param[3].data.d_string, image, drawable, orig_image))
 	    {
@@ -376,44 +382,65 @@ run (gchar   *name,
 	    }
 	  else
 	    {
-	      status = STATUS_EXECUTION_ERROR;
+	      status = GIMP_PDB_EXECUTION_ERROR;
 	    }
 	}
 
-      if (export == EXPORT_EXPORT)
+      if (export == GIMP_EXPORT_EXPORT)
 	gimp_image_delete (image);
     }
   else
     {
-      status = STATUS_CALLING_ERROR;
+      status = GIMP_PDB_CALLING_ERROR;
     }
 
   values[0].data.d_status = status;
 }
 
+static void
+tiff_warning(const char* module, const char* fmt, va_list ap)
+{
+  g_logv (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE, fmt, ap);
+}
+  
+static void
+tiff_error(const char* module, const char* fmt, va_list ap)
+{
+  g_logv (G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE, fmt, ap);
+  gimp_quit ();
+}
+  
 static gint32
 load_image (gchar *filename) 
 {
-  TIFF *tif;
-  unsigned short bps, spp, photomet;
-  int cols, rows, alpha;
-  int image, image_type = RGB;
-  int layer, layer_type = RGB_IMAGE;
-  unsigned short extra, *extra_types;
+  TIFF    *tif;
+  gushort  bps, spp, photomet;
+  gint     cols, rows, alpha;
+  gint     image, image_type = GIMP_RGB;
+  gint     layer, layer_type = GIMP_RGB_IMAGE;
+  gushort  extra, *extra_types;
   channel_data *channel= NULL;
 
-  unsigned short *redmap, *greenmap, *bluemap;
-  guchar colors[3]= {0, 0, 0};
-  guchar cmap[768];
+  gushort *redmap, *greenmap, *bluemap;
+  guchar   colors[3]= {0, 0, 0};
+  guchar   cmap[768];
 
-  int i, j, worst_case = 0;
-  char *name;
+  gint   i, j, worst_case = 0;
+  gchar *name;
 
   TiffSaveVals save_vals;
 #ifdef GIMP_HAVE_PARASITES
-  Parasite *parasite;
+  GimpParasite *parasite;
 #endif /* GIMP_HAVE_PARASITES */
   guint16 tmp;
+#ifdef TIFFTAG_ICCPROFILE
+  uint32 profile_size;
+  guchar *icc_profile;
+#endif
+
+  TIFFSetWarningHandler (tiff_warning);
+  TIFFSetErrorHandler (tiff_error);
+
   tif = TIFFOpen (filename, "r");
   if (!tif) {
     g_message ("TIFF Can't open %s\n", filename);
@@ -473,18 +500,18 @@ load_image (gchar *filename)
   switch (photomet) {
     case PHOTOMETRIC_MINISBLACK:
     case PHOTOMETRIC_MINISWHITE:
-      image_type = GRAY;
-      layer_type = (alpha) ? GRAYA_IMAGE : GRAY_IMAGE;
+      image_type = GIMP_GRAY;
+      layer_type = (alpha) ? GIMP_GRAYA_IMAGE : GIMP_GRAY_IMAGE;
       break;
 
     case PHOTOMETRIC_RGB:
-      image_type = RGB;
-      layer_type = (alpha) ? RGBA_IMAGE : RGB_IMAGE;
+      image_type = GIMP_RGB;
+      layer_type = (alpha) ? GIMP_RGBA_IMAGE : GIMP_RGB_IMAGE;
       break;
 
     case PHOTOMETRIC_PALETTE:
-      image_type = INDEXED;
-      layer_type = (alpha) ? INDEXEDA_IMAGE : INDEXED_IMAGE;
+      image_type = GIMP_INDEXED;
+      layer_type = (alpha) ? GIMP_INDEXEDA_IMAGE : GIMP_INDEXED_IMAGE;
       break;
 
     default:
@@ -492,8 +519,8 @@ load_image (gchar *filename)
   }
 
   if (worst_case) {
-    image_type = RGB;
-    layer_type = RGBA_IMAGE;
+    image_type = GIMP_RGB;
+    layer_type = GIMP_RGBA_IMAGE;
   }
 
   if ((image = gimp_image_new (cols, rows, image_type)) == -1) {
@@ -502,16 +529,31 @@ load_image (gchar *filename)
   }
   gimp_image_set_filename (image, filename);
 
-  /* attach a parasite containing the compression/fillorder */
+  /* attach a parasite containing an ICC profile - if found in the TIFF file */
+
+#ifdef TIFFTAG_ICCPROFILE
+	/* If TIFFTAG_ICCPROFILE is defined we are dealing with a libtiff version 
+         * that can handle ICC profiles. Otherwise just ignore this section. */
+  if (TIFFGetField (tif, TIFFTAG_ICCPROFILE, &profile_size, &icc_profile)) {
+#ifdef GIMP_HAVE_PARASITES
+    parasite = gimp_parasite_new("icc-profile", 0,
+			    profile_size, icc_profile);
+    gimp_image_parasite_attach(image, parasite);
+    gimp_parasite_free(parasite);
+#endif
+  }    
+#endif
+
+  /* attach a parasite containing the compression */
   if (!TIFFGetField (tif, TIFFTAG_COMPRESSION, &tmp))
     save_vals.compression = COMPRESSION_NONE;
   else
     save_vals.compression = tmp;
 #ifdef GIMP_HAVE_PARASITES
-  parasite = parasite_new("tiff-save-options", 0,
-			  sizeof(save_vals), &save_vals);
-  gimp_image_parasite_attach(image, parasite);
-  parasite_free(parasite);
+  parasite = gimp_parasite_new ("tiff-save-options", 0,
+				sizeof (save_vals), &save_vals);
+  gimp_image_parasite_attach (image, parasite);
+  gimp_parasite_free (parasite);
 #endif /* GIMP_HAVE_PARASITES */
 
 
@@ -530,10 +572,11 @@ load_image (gchar *filename)
       len = MIN(len, 241);
       img_desc[len-1] = '\000';
 
-      parasite = parasite_new ("gimp-comment", PARASITE_PERSISTENT,
-			       len, img_desc);
+      parasite = gimp_parasite_new ("gimp-comment",
+				    GIMP_PARASITE_PERSISTENT,
+				    len, img_desc);
       gimp_image_parasite_attach (image, parasite);
-      parasite_free (parasite);
+      gimp_parasite_free (parasite);
     }
   }
 #endif /* GIMP_HAVE_PARASITES */
@@ -611,7 +654,7 @@ load_image (gchar *filename)
 
 
   /* Install colormap for INDEXED images only */
-  if (image_type == INDEXED) 
+  if (image_type == GIMP_INDEXED) 
     {
       if (!TIFFGetField (tif, TIFFTAG_COLORMAP, &redmap, &greenmap, &bluemap)) 
 	{
@@ -631,7 +674,7 @@ load_image (gchar *filename)
   /* Allocate channel_data for all channels, even the background layer */
   channel = g_new (channel_data, extra + 1);
   layer = gimp_layer_new (image, _("Background"), cols, rows, layer_type,
-			     100, NORMAL_MODE);
+			     100, GIMP_NORMAL_MODE);
   channel[0].ID= layer;
   gimp_image_add_layer (image, layer, 0);
   channel[0].drawable= gimp_drawable_get(layer);
@@ -792,13 +835,19 @@ load_lines (TIFF *tif, channel_data *channel,
 }
 
 static void
-read_16bit (guchar *source, channel_data *channel, unsigned short photomet,
-	    int startrow, int startcol, int rows, int cols,
-	    int alpha, int extra)
+read_16bit (guchar       *source,
+	    channel_data *channel,
+	    gushort       photomet,
+	    gint          startrow,
+	    gint          startcol,
+	    gint          rows,
+	    gint          cols,
+	    gint          alpha,
+	    gint          extra)
 {
   guchar *dest;
-  int gray_val, red_val, green_val, blue_val, alpha_val;
-  int col, row, i;
+  gint    gray_val, red_val, green_val, blue_val, alpha_val;
+  gint    col, row, i;
 
   for (i= 0; i <= extra; ++i) {
     gimp_pixel_rgn_init (&(channel[i].pixel_rgn), channel[i].drawable,
@@ -886,13 +935,19 @@ read_16bit (guchar *source, channel_data *channel, unsigned short photomet,
 }
 
 static void
-read_8bit (guchar *source, channel_data *channel, unsigned short photomet,
-	   int startrow, int startcol, int rows, int cols,
-	   int alpha, int extra)
+read_8bit (guchar       *source,
+	   channel_data *channel,
+	   gushort       photomet,
+	   gint          startrow,
+	   gint          startcol,
+	   gint          rows,
+	   gint          cols,
+	   gint          alpha,
+	   gint          extra)
 {
   guchar *dest;
-  int gray_val, red_val, green_val, blue_val, alpha_val;
-  int col, row, i;
+  gint    gray_val, red_val, green_val, blue_val, alpha_val;
+  gint    col, row, i;
 
   for (i= 0; i <= extra; ++i) {
     gimp_pixel_rgn_init (&(channel[i].pixel_rgn), channel[i].drawable,
@@ -993,15 +1048,21 @@ read_8bit (guchar *source, channel_data *channel, unsigned short photomet,
   }
 
 static void
-read_default (guchar *source, channel_data *channel,
-	      unsigned short bps, unsigned short photomet,
-	      int startrow, int startcol, int rows, int cols,
-	      int alpha, int extra)
+read_default (guchar       *source,
+	      channel_data *channel,
+	      gushort       bps,
+	      gushort       photomet,
+	      gint          startrow,
+	      gint          startcol,
+	      gint          rows,
+	      gint          cols,
+	      gint          alpha,
+	      gint          extra)
 {
   guchar *dest;
-  int gray_val, red_val, green_val, blue_val, alpha_val;
-  int col, row, i;
-  int bitsleft = 8, maxval = (1 << bps) - 1;
+  gint    gray_val, red_val, green_val, blue_val, alpha_val;
+  gint    col, row, i;
+  gint    bitsleft = 8, maxval = (1 << bps) - 1;
 
   for (i= 0; i <= extra; ++i) {
     gimp_pixel_rgn_init (&(channel[i].pixel_rgn), channel[i].drawable,
@@ -1093,14 +1154,21 @@ read_default (guchar *source, channel_data *channel,
 }
 
 static void
-read_separate (guchar *source, channel_data *channel,
-               unsigned short bps, unsigned short photomet,
-               int startrow, int startcol, int rows, int cols,
-               int alpha, int extra, int sample)
+read_separate (guchar       *source,
+	       channel_data *channel,
+               gushort       bps,
+	       gushort       photomet,
+               gint          startrow,
+	       gint          startcol,
+	       gint          rows,
+	       gint          cols,
+               gint          alpha,
+	       gint          extra,
+	       gint          sample)
 {
   guchar *dest;
-  int col, row, c;
-  int bitsleft = 8, maxval = (1 << bps) - 1;
+  gint    col, row, c;
+  gint    bitsleft = 8, maxval = (1 << bps) - 1;
 
   if (bps > 8) {
     g_message("TIFF Unsupported layout\n");
@@ -1157,42 +1225,52 @@ read_separate (guchar *source, channel_data *channel,
 ** other special, indirect and consequential damages.
 */
 
-static gint save_image (char   *filename, 
-			gint32  image, 
-			gint32  layer,
-			gint32  orig_image)  /* the export function might have created a duplicate */  
+static gint
+save_image (gchar   *filename, 
+	    gint32   image, 
+	    gint32   layer,
+	    gint32   orig_image)  /* the export function might have created a duplicate */  
 {
-  TIFF *tif;
-  unsigned short red[256];
-  unsigned short grn[256];
-  unsigned short blu[256];
-  int cols, col, rows, row, i;
-  long g3options;
-  long rowsperstrip;
-  unsigned short compression;
-  unsigned short extra_samples[1];
-  int alpha;
-  short predictor;
-  short photometric;
-  short samplesperpixel;
-  short bitspersample;
-  int bytesperrow;
-  guchar *t, *src, *data;
-  guchar *cmap;
-  int colors;
-  int success;
-  GDrawable *drawable;
-  GDrawableType drawable_type;
-  GPixelRgn pixel_rgn;
-  int tile_height;
-  int y, yend;
-  char *name;
+  TIFF          *tif;
+  gushort        red[256];
+  gushort        grn[256];
+  gushort        blu[256];
+  gint           cols, col, rows, row, i;
+  glong          rowsperstrip;
+  gushort        compression;
+  gushort        extra_samples[1];
+  gint           alpha;
+  gshort         predictor;
+  gshort         photometric;
+  gshort         samplesperpixel;
+  gshort         bitspersample;
+  gint           bytesperrow;
+  guchar        *t, *src, *data;
+  guchar        *cmap;
+  gint           colors;
+  gint           success;
+  GimpDrawable     *drawable;
+  GimpImageType  drawable_type;
+  GimpPixelRgn      pixel_rgn;
+  gint           tile_height;
+  gint           y, yend;
+  gchar         *name;
 
   compression = tsvals.compression;
 
-  g3options = 0;
+  /* Disabled because this isn't in older releases of libtiff, and it
+     wasn't helping much anyway */
+#if 0
+  if (TIFFFindCODEC((uint16) compression) == NULL)
+    compression = COMPRESSION_NONE; /* CODEC not available */
+#endif
+
   predictor = 0;
-  rowsperstrip = 0;
+  tile_height = gimp_tile_height ();
+  rowsperstrip = tile_height;
+
+  TIFFSetWarningHandler (tiff_warning);
+  TIFFSetErrorHandler (tiff_error);
 
   tif = TIFFOpen (filename, "w");
   if (!tif) 
@@ -1203,18 +1281,19 @@ static gint save_image (char   *filename,
 
   name = g_strdup_printf( _("Saving %s:"), filename);
   gimp_progress_init (name);
-  free (name);
+  g_free (name);
 
   drawable = gimp_drawable_get (layer);
   drawable_type = gimp_drawable_type (layer);
-  gimp_pixel_rgn_init (&pixel_rgn, drawable, 0, 0, drawable->width, drawable->height, FALSE, FALSE);
+  gimp_pixel_rgn_init (&pixel_rgn, drawable,
+		       0, 0, drawable->width, drawable->height, FALSE, FALSE);
 
   cols = drawable->width;
   rows = drawable->height;
 
   switch (drawable_type)
     {
-    case RGB_IMAGE:
+    case GIMP_RGB_IMAGE:
       predictor = 2;
       samplesperpixel = 3;
       bitspersample = 8;
@@ -1222,14 +1301,14 @@ static gint save_image (char   *filename,
       bytesperrow = cols * 3;
       alpha = 0;
       break;
-    case GRAY_IMAGE:
+    case GIMP_GRAY_IMAGE:
       samplesperpixel = 1;
       bitspersample = 8;
       photometric = PHOTOMETRIC_MINISBLACK;
       bytesperrow = cols;
       alpha = 0;
       break;
-    case RGBA_IMAGE:
+    case GIMP_RGBA_IMAGE:
       predictor = 2;
       samplesperpixel = 4;
       bitspersample = 8;
@@ -1237,14 +1316,14 @@ static gint save_image (char   *filename,
       bytesperrow = cols * 4;
       alpha = 1;
       break;
-    case GRAYA_IMAGE:
+    case GIMP_GRAYA_IMAGE:
       samplesperpixel = 2;
       bitspersample = 8;
       photometric = PHOTOMETRIC_MINISBLACK;
       bytesperrow = cols * 2;
       alpha = 1;
       break;
-    case INDEXED_IMAGE:
+    case GIMP_INDEXED_IMAGE:
       samplesperpixel = 1;
       bitspersample = 8;
       photometric = PHOTOMETRIC_PALETTE;
@@ -1260,17 +1339,12 @@ static gint save_image (char   *filename,
 	  blu[i] = *cmap++ * 65535 / 255;
 	}
       break;
-    case INDEXEDA_IMAGE:
+    case GIMP_INDEXEDA_IMAGE:
       return 0;
      default:
       return 0;
     }
 
-  if (rowsperstrip == 0)
-    rowsperstrip = (8 * 1024) / bytesperrow;
-  if (rowsperstrip == 0)
-    rowsperstrip = 1;
-
   /* Set TIFF parameters. */
   TIFFSetField (tif, TIFFTAG_SUBFILETYPE, 0);
   TIFFSetField (tif, TIFFTAG_IMAGEWIDTH, cols);
@@ -1278,13 +1352,14 @@ static gint save_image (char   *filename,
   TIFFSetField (tif, TIFFTAG_BITSPERSAMPLE, bitspersample);
   TIFFSetField (tif, TIFFTAG_ORIENTATION, ORIENTATION_TOPLEFT);
   TIFFSetField (tif, TIFFTAG_COMPRESSION, compression);
-  if ((compression == COMPRESSION_LZW) && (predictor != 0))
+  if ((compression == COMPRESSION_LZW || compression == COMPRESSION_DEFLATE)
+     && (predictor != 0)) {
     TIFFSetField (tif, TIFFTAG_PREDICTOR, predictor);
-  if (alpha)
-    {
+  }
+  if (alpha) {
       extra_samples [0] = EXTRASAMPLE_ASSOCALPHA;
       TIFFSetField (tif, TIFFTAG_EXTRASAMPLES, 1, extra_samples);
-    }
+  }
   TIFFSetField (tif, TIFFTAG_PHOTOMETRIC, photometric);
   TIFFSetField (tif, TIFFTAG_DOCUMENTNAME, filename);
   TIFFSetField (tif, TIFFTAG_SAMPLESPERPIXEL, samplesperpixel);
@@ -1332,21 +1407,42 @@ static gint save_image (char   *filename,
 #ifdef GIMP_HAVE_PARASITES
   if (image_comment && *image_comment != '\000')
     {
-      Parasite *parasite;
+      GimpParasite *parasite;
       
       TIFFSetField (tif, TIFFTAG_IMAGEDESCRIPTION, image_comment);
-      parasite = parasite_new ("gimp-comment", 1,
-			       strlen (image_comment) + 1, image_comment);
+      parasite = gimp_parasite_new ("gimp-comment",
+				    GIMP_PARASITE_PERSISTENT,
+				    strlen (image_comment) + 1, image_comment);
       gimp_image_parasite_attach (orig_image, parasite);
-      parasite_free (parasite);
+      gimp_parasite_free (parasite);
     }
 #endif /* GIMP_HAVE_PARASITES */
 
-  if (drawable_type == INDEXED_IMAGE)
+  /* do we have an ICC profile? If so, write it to the TIFF file */
+#ifdef GIMP_HAVE_PARASITES
+#ifdef TIFFTAG_ICCPROFILE
+  {
+    GimpParasite *parasite;
+    uint32 profile_size;
+    guchar *icc_profile;
+
+    parasite = gimp_image_parasite_find (orig_image, "icc-profile");
+    if (parasite)
+      {
+        profile_size = gimp_parasite_data_size(parasite);
+	icc_profile = gimp_parasite_data(parasite);
+
+	TIFFSetField(tif, TIFFTAG_ICCPROFILE, profile_size, icc_profile);
+        gimp_parasite_free(parasite);
+      }
+  }
+#endif
+#endif
+
+  if (drawable_type == GIMP_INDEXED_IMAGE)
     TIFFSetField (tif, TIFFTAG_COLORMAP, red, grn, blu);
 
   /* array to rearrange data */
-  tile_height = gimp_tile_height ();
   src = g_new (guchar, bytesperrow * tile_height);
   data = g_new (guchar, bytesperrow);
 
@@ -1364,13 +1460,13 @@ static gint save_image (char   *filename,
 
 	  switch (drawable_type)
 	    {
-	    case INDEXED_IMAGE:
+	    case GIMP_INDEXED_IMAGE:
 	      success = (TIFFWriteScanline (tif, t, row, 0) >= 0);
 	      break;
-	    case GRAY_IMAGE:
+	    case GIMP_GRAY_IMAGE:
 	      success = (TIFFWriteScanline (tif, t, row, 0) >= 0);
 	      break;
-	    case GRAYA_IMAGE:
+	    case GIMP_GRAYA_IMAGE:
 	      for (col = 0; col < cols*samplesperpixel; col+=samplesperpixel)
 		{
 		  /* pre-multiply gray by alpha */
@@ -1379,10 +1475,10 @@ static gint save_image (char   *filename,
 		}
 	      success = (TIFFWriteScanline (tif, data, row, 0) >= 0);
 	      break;
-	    case RGB_IMAGE:
+	    case GIMP_RGB_IMAGE:
 	      success = (TIFFWriteScanline (tif, t, row, 0) >= 0);
 	      break;
-	    case RGBA_IMAGE:
+	    case GIMP_RGBA_IMAGE:
 	      for (col = 0; col < cols*samplesperpixel; col+=samplesperpixel)
 		{
 		  /* pre-multiply rgb by alpha */
@@ -1399,8 +1495,8 @@ static gint save_image (char   *filename,
 	    }
 
 	  if (!success) {
-	      g_message("TIFF Failed a scanline write on row %d", row);
-	      return 0;
+	    g_message ("TIFF Failed a scanline write on row %d", row);
+	    return 0;
 	  }
 	}
 
@@ -1416,20 +1512,6 @@ static gint save_image (char   *filename,
   return 1;
 }
 
-static void 
-init_gtk (void)
-{
-  gchar **argv;
-  gint    argc;
-
-  argc    = 1;
-  argv    = g_new (gchar *, 1);
-  argv[0] = g_strdup ("tiff");
-
-  gtk_init (&argc, &argv);
-  gtk_rc_parse (gimp_gtkrc ());
-}
-
 static gint
 save_dialog (void)
 {
@@ -1441,7 +1523,7 @@ save_dialog (void)
   GtkWidget *entry;
 
   dlg = gimp_dialog_new ( _("Save as TIFF"), "tiff",
-			 gimp_plugin_help_func, "filters/tiff.html",
+			 gimp_standard_help_func, "filters/tiff.html",
 			 GTK_WIN_POS_MOUSE,
 			 FALSE, TRUE, FALSE,
 
@@ -1469,6 +1551,8 @@ save_dialog (void)
 			   _("None"),      (gpointer) COMPRESSION_NONE, NULL,
 			   _("LZW"),       (gpointer) COMPRESSION_LZW, NULL,
 			   _("Pack Bits"), (gpointer) COMPRESSION_PACKBITS, NULL,
+			   _("Deflate"),   (gpointer) COMPRESSION_DEFLATE, NULL,
+			   _("JPEG"),      (gpointer) COMPRESSION_JPEG, NULL,
 
 			   NULL);
   gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
