@@ -1,7 +1,7 @@
 /* The GIMP -- an image manipulation program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  * XWD reading and writing code Copyright (C) 1996 Peter Kirchgessner
- * (email: pkirchg@aol.com, WWW: http://members.aol.com/pkirchg)
+ * (email: peter@kirchgessner.net, WWW: http://www.kirchgessner.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
  *          2       |    1,...,24  |      32
  */
 /* Event history:
+ * PK = Peter Kirchgessner, ME = Mattias Engdegrd
  * V 1.00, PK, xx-Aug-96: First try
  * V 1.01, PK, 03-Sep-96: Check for bitmap_bit_order
  * V 1.90, PK, 17-Mar-97: Upgrade to work with GIMP V0.99
@@ -43,8 +44,10 @@
  * V 1.91, PK, 05-Apr-97: Return all arguments, even in case of an error
  * V 1.92, PK, 12-Oct-97: No progress bars for non-interactive mode
  * V 1.93, PK, 11-Apr-98: Fix problem with overwriting memory
+ * V 1.94, ME, 27-Feb-00: Remove superfluous little-endian support (format is
+                          specified as big-endian). Trim magic header
  */
-static char ident[] = "@(#) GIMP XWD file-plugin v1.93  11-Apr-98";
+static char ident[] = "@(#) GIMP XWD file-plugin v1.94  27-Feb-2000";
 
 #include "config.h"
 
@@ -62,9 +65,10 @@ static char ident[] = "@(#) GIMP XWD file-plugin v1.93  11-Apr-98";
 
 #include "libgimp/stdplugins-intl.h"
 
-typedef unsigned long L_CARD32;
-typedef unsigned short L_CARD16;
-typedef unsigned char L_CARD8;
+
+typedef gulong  L_CARD32;
+typedef gushort L_CARD16;
+typedef guchar  L_CARD8;
 
 typedef struct
 {
@@ -135,19 +139,17 @@ typedef struct
 static void   query               (void);
 static void   run                 (gchar   *name,
 				   gint     nparams,
-				   GParam  *param,
+				   GimpParam  *param,
 				   gint    *nreturn_vals,
-				   GParam **return_vals);
+				   GimpParam **return_vals);
 
-static void   init_gtk            (void);
-
-static gint32 load_image          (gchar *filename);
-static gint   save_image          (gchar *filename,
-				   gint32 image_ID,
-				   gint32 drawable_ID);
+static gint32 load_image          (gchar  *filename);
+static gint   save_image          (gchar  *filename,
+				   gint32  image_ID,
+				   gint32  drawable_ID);
 static gint32 create_new_image    (char *filename, guint width, guint height,
-				   GImageType type, gint32 *layer_ID, 
-				   GDrawable **drawable, GPixelRgn *pixel_rgn);
+				   GimpImageBaseType type, gint32 *layer_ID, 
+				   GimpDrawable **drawable, GimpPixelRgn *pixel_rgn);
 
 static int    set_pixelmap        (int, L_XWDCOLOR *,PIXEL_MAP *);
 static int    get_pixelmap        (L_CARD32, PIXEL_MAP *,unsigned char *,
@@ -183,10 +185,7 @@ static gint save_index       (FILE *, gint32, gint32, int);
 static gint save_rgb         (FILE *, gint32, gint32);
 
 
-static int read_msb_first = 1;
-
-
-GPlugInInfo PLUG_IN_INFO =
+GimpPlugInInfo PLUG_IN_INFO =
 {
   NULL,  /* init_proc  */
   NULL,  /* quit_proc  */
@@ -196,7 +195,7 @@ GPlugInInfo PLUG_IN_INFO =
 
 
 /* The run mode */
-static GRunModeType l_run_mode;
+static GimpRunModeType l_run_mode;
 
 
 MAIN ()
@@ -206,32 +205,31 @@ static void
 query (void)
 
 {
-  static GParamDef load_args[] =
+  static GimpParamDef load_args[] =
   {
-    { PARAM_INT32,  "run_mode",     "Interactive, non-interactive" },
-    { PARAM_STRING, "filename",     "The name of the file to load" },
-    { PARAM_STRING, "raw_filename", "The name of the file to load" },
-  };
-  static GParamDef load_return_vals[] =
-  {
-    { PARAM_IMAGE,  "image",        "Output image" },
+    { GIMP_PDB_INT32,  "run_mode",     "Interactive, non-interactive" },
+    { GIMP_PDB_STRING, "filename",     "The name of the file to load" },
+    { GIMP_PDB_STRING, "raw_filename", "The name of the file to load" }
   };
   static gint nload_args = sizeof (load_args) / sizeof (load_args[0]);
+
+  static GimpParamDef load_return_vals[] =
+  {
+    { GIMP_PDB_IMAGE,  "image",        "Output image" }
+  };
   static gint nload_return_vals = (sizeof (load_return_vals) /
 				   sizeof (load_return_vals[0]));
 
-  static GParamDef save_args[] =
+  static GimpParamDef save_args[] =
   {
-    { PARAM_INT32,    "run_mode",     "Interactive, non-interactive" },
-    { PARAM_IMAGE,    "image",        "Input image" },
-    { PARAM_DRAWABLE, "drawable",     "Drawable to save" },
-    { PARAM_STRING,   "filename",     "The name of the file to save the image in" },
-    { PARAM_STRING,   "raw_filename", "The name of the file to save the image in" }
+    { GIMP_PDB_INT32,    "run_mode",     "Interactive, non-interactive" },
+    { GIMP_PDB_IMAGE,    "image",        "Input image" },
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save" },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
+    { GIMP_PDB_STRING,   "raw_filename", "The name of the file to save the image in" }
   };
   static gint nsave_args = sizeof (save_args) / sizeof (save_args[0]);
 
-  INIT_I18N();
-
   gimp_install_procedure ("file_xwd_load",
                           "load file of the XWD file format",
                           "load file of the XWD file format",
@@ -240,7 +238,7 @@ query (void)
                           "1996",
                           "<Load>/XWD",
                           NULL,
-                          PROC_PLUG_IN,
+                          GIMP_PLUGIN,
                           nload_args, nload_return_vals,
                           load_args, load_return_vals);
 
@@ -253,41 +251,40 @@ those with alpha channels.",
                           "1996",
                           "<Save>/XWD",
                           "RGB, GRAY, INDEXED",
-                          PROC_PLUG_IN,
+                          GIMP_PLUGIN,
                           nsave_args, 0,
                           save_args, NULL);
 
   gimp_register_magic_load_handler ("file_xwd_load",
 				    "xwd",
 				    "",
-                                    "4,long,0x00000007,4,long,0x07000000");
-  gimp_register_save_handler       ("file_xwd_save",
-				    "xwd",
-				    "");
+                                    "4,long,0x00000007");
+  gimp_register_save_handler ("file_xwd_save",
+			      "xwd",
+			      "");
 }
 
 
 static void
 run (gchar   *name,
      gint     nparams,
-     GParam  *param,
+     GimpParam  *param,
      gint    *nreturn_vals,
-     GParam **return_vals)
-
+     GimpParam **return_vals)
 {
-  static GParam values[2];
-  GRunModeType  run_mode;
-  GStatusType   status = STATUS_SUCCESS;
+  static GimpParam values[2];
+  GimpRunModeType  run_mode;
+  GimpPDBStatusType   status = GIMP_PDB_SUCCESS;
   gint32        image_ID;
   gint32        drawable_ID;
-  GimpExportReturnType export = EXPORT_CANCEL;
+  GimpExportReturnType export = GIMP_EXPORT_CANCEL;
 
   l_run_mode = run_mode = param[0].data.d_int32;
 
   *nreturn_vals = 1;
   *return_vals  = values;
-  values[0].type          = PARAM_STATUS;
-  values[0].data.d_status = STATUS_EXECUTION_ERROR;
+  values[0].type          = GIMP_PDB_STATUS;
+  values[0].data.d_status = GIMP_PDB_EXECUTION_ERROR;
 
   if (strcmp (name, "file_xwd_load") == 0)
     {
@@ -298,12 +295,12 @@ run (gchar   *name,
       if (image_ID != -1)
 	{
 	  *nreturn_vals = 2;
-	  values[1].type         = PARAM_IMAGE;
+	  values[1].type         = GIMP_PDB_IMAGE;
 	  values[1].data.d_image = image_ID;
 	}
       else
 	{
-	  status = STATUS_EXECUTION_ERROR;
+	  status = GIMP_PDB_EXECUTION_ERROR;
 	}
     }
   else if (strcmp (name, "file_xwd_save") == 0)
@@ -316,16 +313,16 @@ run (gchar   *name,
       /*  eventually export the image */ 
       switch (run_mode)
 	{
-	case RUN_INTERACTIVE:
-	case RUN_WITH_LAST_VALS:
-	  init_gtk ();
+	case GIMP_RUN_INTERACTIVE:
+	case GIMP_RUN_WITH_LAST_VALS:
+	  gimp_ui_init ("xwd", FALSE);
 	  export = gimp_export_image (&image_ID, &drawable_ID, "XWD", 
-				      (CAN_HANDLE_RGB |
-				       CAN_HANDLE_GRAY |
-				       CAN_HANDLE_INDEXED));
-	  if (export == EXPORT_CANCEL)
+				      (GIMP_EXPORT_CAN_HANDLE_RGB |
+				       GIMP_EXPORT_CAN_HANDLE_GRAY |
+				       GIMP_EXPORT_CAN_HANDLE_INDEXED));
+	  if (export == GIMP_EXPORT_CANCEL)
 	    {
-	      values[0].data.d_status = STATUS_CANCEL;
+	      values[0].data.d_status = GIMP_PDB_CANCEL;
 	      return;
 	  }
 	  break;
@@ -335,53 +332,39 @@ run (gchar   *name,
  
       switch (run_mode)
         {
-        case RUN_INTERACTIVE:
-        case RUN_WITH_LAST_VALS:
+        case GIMP_RUN_INTERACTIVE:
+        case GIMP_RUN_WITH_LAST_VALS:
           /* No additional data to retrieve */
           break;
 
-        case RUN_NONINTERACTIVE:
+        case GIMP_RUN_NONINTERACTIVE:
           /*  Make sure all the arguments are there!  */
           if (nparams != 5)
-            status = STATUS_CALLING_ERROR;
+            status = GIMP_PDB_CALLING_ERROR;
           break;
 
         default:
           break;
         }
 
-      if (status == STATUS_SUCCESS)
+      if (status == GIMP_PDB_SUCCESS)
 	{
 	  if (! save_image (param[3].data.d_string, image_ID, drawable_ID))
 	    {
-	      status = STATUS_EXECUTION_ERROR;
+	      status = GIMP_PDB_EXECUTION_ERROR;
 	    }
 	}
-      if (export == EXPORT_EXPORT)
+      if (export == GIMP_EXPORT_EXPORT)
 	gimp_image_delete (image_ID);
     }
   else
     {
-      status = STATUS_CANCEL;
+      status = GIMP_PDB_CANCEL;
     }
 
   values[0].data.d_status = status;
 }
 
-static void 
-init_gtk (void)
-{
-  gchar **argv;
-  gint    argc;
-
-  argc    = 1;
-  argv    = g_new (gchar *, 1);
-  argv[0] = g_strdup ("xwd");
-  
-  gtk_init (&argc, &argv);
-  gtk_rc_parse (gimp_gtkrc ());
-}
-
 static gint32
 load_image (gchar *filename)
 {
@@ -399,22 +382,12 @@ load_image (gchar *filename)
       return (-1);
     }
 
-  read_msb_first = 1;   /* Start reading with most significant byte first */
-
   read_xwd_header (ifp, &xwdhdr);
   if (xwdhdr.l_file_version != 7)
     {
-      read_msb_first = 0; /* Try reading with least significant byte first */
-
-      fseek (ifp, 0, SEEK_SET);
-
-      read_xwd_header (ifp, &xwdhdr);
-      if (xwdhdr.l_file_version != 7)
-	{
-	  g_message(_("can't open file as XWD file"));
-	  fclose (ifp);
-	  return (-1);
-	}
+      g_message(_("can't open file as XWD file"));
+      fclose (ifp);
+      return (-1);
     }
 
   /* Position to start of XWDColor structures */
@@ -452,7 +425,7 @@ load_image (gchar *filename)
       }
     }
 
-  if (l_run_mode != RUN_NONINTERACTIVE)
+  if (l_run_mode != GIMP_RUN_NONINTERACTIVE)
     {
       temp = g_strdup_printf (_("Loading %s:"), filename);
       gimp_progress_init (temp);
@@ -523,7 +496,7 @@ save_image (char   *filename,
 
 {
   FILE* ofp;
-  GDrawableType drawable_type;
+  GimpImageType drawable_type;
   gint retval;
   char *temp;
 
@@ -538,9 +511,9 @@ save_image (char   *filename,
 
   switch (drawable_type)
     {
-    case INDEXED_IMAGE:
-    case GRAY_IMAGE:
-    case RGB_IMAGE:
+    case GIMP_INDEXED_IMAGE:
+    case GIMP_GRAY_IMAGE:
+    case GIMP_RGB_IMAGE:
       break;
     default:
       g_message (_("cannot operate on unknown image types"));
@@ -556,18 +529,18 @@ save_image (char   *filename,
       return (FALSE);
     }
 
-  if (l_run_mode != RUN_NONINTERACTIVE)
+  if (l_run_mode != GIMP_RUN_NONINTERACTIVE)
     {
       temp = g_strdup_printf (_("Saving %s:"), filename);
       gimp_progress_init (temp);
       g_free (temp);
     }
 
-  if (drawable_type == INDEXED_IMAGE)
+  if (drawable_type == GIMP_INDEXED_IMAGE)
     retval = save_index (ofp, image_ID, drawable_ID, 0);
-  else if (drawable_type == GRAY_IMAGE)
+  else if (drawable_type == GIMP_GRAY_IMAGE)
     retval = save_index (ofp, image_ID, drawable_ID, 1);
-  else if (drawable_type == RGB_IMAGE)
+  else if (drawable_type == GIMP_RGB_IMAGE)
     retval = save_rgb (ofp, image_ID, drawable_ID);
   else
     retval = FALSE;
@@ -585,20 +558,10 @@ read_card32 (FILE *ifp,
 {
   L_CARD32 c;
 
-  if (read_msb_first)
-    {
-      c = (((L_CARD32)(getc (ifp))) << 24);
-      c |= (((L_CARD32)(getc (ifp))) << 16);
-     c |= (((L_CARD32)(getc (ifp))) << 8);
-     c |= ((L_CARD32)(*err = getc (ifp)));
-    }
-  else
-    {
-      c = ((L_CARD32)(getc (ifp)));
-      c |= (((L_CARD32)(getc (ifp))) << 8);
-      c |= (((L_CARD32)(getc (ifp))) << 16);
-      c |= (((L_CARD32)(*err = getc (ifp))) << 24);
-    }
+  c = (((L_CARD32)(getc (ifp))) << 24);
+  c |= (((L_CARD32)(getc (ifp))) << 16);
+  c |= (((L_CARD32)(getc (ifp))) << 8);
+  c |= ((L_CARD32)(*err = getc (ifp)));
   
   *err = (*err < 0);
   return (c);
@@ -612,16 +575,8 @@ read_card16 (FILE *ifp,
 {
   L_CARD16 c;
   
-  if (read_msb_first)
-    {
-      c = (((L_CARD16)(getc (ifp))) << 8);
-      c |= ((L_CARD16)(*err = getc (ifp)));
-    }
-  else
-    {
-      c = ((L_CARD16)(getc (ifp)));
-      c |= (((L_CARD16)(*err = getc (ifp))) << 8);
-    }
+  c = (((L_CARD16)(getc (ifp))) << 8);
+  c |= ((L_CARD16)(*err = getc (ifp)));
   
   *err = (*err < 0);
   return (c);
@@ -1043,27 +998,36 @@ static gint32
 create_new_image (char         *filename, 
                   guint         width,
                   guint         height,
-                  GImageType    type,
+                  GimpImageBaseType    type,
                   gint32       *layer_ID,
-                  GDrawable   **drawable,
-                  GPixelRgn    *pixel_rgn)
+                  GimpDrawable   **drawable,
+                  GimpPixelRgn    *pixel_rgn)
 
 {
   gint32 image_ID;
-  GDrawableType gdtype;
+  GimpImageType gdtype;
+  
+  switch (type)
+    {
+    case GIMP_GRAY: 
+      gdtype = GIMP_GRAY_IMAGE;
+      break;
+    case GIMP_INDEXED: 
+      gdtype = GIMP_INDEXED_IMAGE;
+      break;
+    case GIMP_RGB:
+      gdtype = GIMP_RGB_IMAGE;
+      break;
+    default:
+      g_warning ("Unknown image type");
+      return -1;
+    }
   
-  if (type == GRAY) 
-    gdtype = GRAY_IMAGE;
-  else if (type == INDEXED) 
-    gdtype = INDEXED_IMAGE;
-  else 
-    gdtype = RGB_IMAGE;
-
   image_ID = gimp_image_new (width, height, type);
   gimp_image_set_filename (image_ID, filename);
   
   *layer_ID = gimp_layer_new (image_ID, "Background", width, height,
-			      gdtype, 100, NORMAL_MODE);
+			      gdtype, 100, GIMP_NORMAL_MODE);
   gimp_image_add_layer (image_ID, *layer_ID, 0);
   
   *drawable = gimp_drawable_get (*layer_ID);
@@ -1091,8 +1055,8 @@ load_xwd_f2_d1_b1 (char            *filename,
   unsigned char *data, *scanline;
   int err = 0;
   gint32 layer_ID, image_ID;
-  GPixelRgn pixel_rgn;
-  GDrawable *drawable;
+  GimpPixelRgn pixel_rgn;
+  GimpDrawable *drawable;
   
 #ifdef XWD_DEBUG
   printf ("load_xwd_f2_d1_b1 (%s)\n", filename);
@@ -1101,7 +1065,7 @@ load_xwd_f2_d1_b1 (char            *filename,
   width = xwdhdr->l_pixmap_width;
   height = xwdhdr->l_pixmap_height;
   
-  image_ID = create_new_image (filename, width, height, INDEXED,
+  image_ID = create_new_image (filename, width, height, GIMP_INDEXED,
 			       &layer_ID, &drawable, &pixel_rgn);
   
   tile_height = gimp_tile_height ();
@@ -1193,7 +1157,7 @@ load_xwd_f2_d1_b1 (char            *filename,
       
       scan_lines++;
       
-      if ((l_run_mode != RUN_NONINTERACTIVE) && ((i % 20) == 0))
+      if ((l_run_mode != GIMP_RUN_NONINTERACTIVE) && ((i % 20) == 0))
 	gimp_progress_update ((double)(i+1) / (double)height);
       
       if ((scan_lines == tile_height) || ((i+1) == height))
@@ -1231,8 +1195,8 @@ load_xwd_f2_d8_b8 (char            *filename,
   unsigned char *dest, *data;
   int err = 0;
   gint32 layer_ID, image_ID;
-  GPixelRgn pixel_rgn;
-  GDrawable *drawable;
+  GimpPixelRgn pixel_rgn;
+  GimpDrawable *drawable;
   
 #ifdef XWD_DEBUG
   printf ("load_xwd_f2_d8_b8 (%s)\n", filename);
@@ -1257,7 +1221,7 @@ load_xwd_f2_d8_b8 (char            *filename,
     }
   
   image_ID = create_new_image (filename, width, height,
-			       greyscale ? GRAY : INDEXED,
+			       greyscale ? GIMP_GRAY : GIMP_INDEXED,
 			       &layer_ID, &drawable, &pixel_rgn);
   
   tile_height = gimp_tile_height ();
@@ -1293,7 +1257,7 @@ load_xwd_f2_d8_b8 (char            *filename,
       
       scan_lines++;
       
-      if ((l_run_mode != RUN_NONINTERACTIVE) && ((i % 20) == 0))
+      if ((l_run_mode != GIMP_RUN_NONINTERACTIVE) && ((i % 20) == 0))
 	gimp_progress_update ((double)(i+1) / (double)height);
       
       if ((scan_lines == tile_height) || ((i+1) == height))
@@ -1334,8 +1298,8 @@ load_xwd_f2_d16_b16 (char            *filename,
   unsigned char *ColorMap, *cm, *data;
   int err = 0;
   gint32 layer_ID, image_ID;
-  GPixelRgn pixel_rgn;
-  GDrawable *drawable;
+  GimpPixelRgn pixel_rgn;
+  GimpDrawable *drawable;
   
 #ifdef XWD_DEBUG
   printf ("load_xwd_f2_d16_b16 (%s)\n", filename);
@@ -1344,7 +1308,7 @@ load_xwd_f2_d16_b16 (char            *filename,
   width = xwdhdr->l_pixmap_width;
   height = xwdhdr->l_pixmap_height;
   
-  image_ID = create_new_image (filename, width, height, RGB,
+  image_ID = create_new_image (filename, width, height, GIMP_RGB,
 			       &layer_ID, &drawable, &pixel_rgn);
   
   tile_height = gimp_tile_height ();
@@ -1454,7 +1418,7 @@ load_xwd_f2_d16_b16 (char            *filename,
       
       scan_lines++;
       
-      if ((l_run_mode != RUN_NONINTERACTIVE) && ((i % 20) == 0))
+      if ((l_run_mode != GIMP_RUN_NONINTERACTIVE) && ((i % 20) == 0))
 	gimp_progress_update ((double)(i+1) / (double)height);
       
       if ((scan_lines == tile_height) || ((i+1) == height))
@@ -1498,8 +1462,8 @@ load_xwd_f2_d24_b32 (char            *filename,
   PIXEL_MAP pixel_map;
   int err = 0;
   gint32 layer_ID, image_ID;
-  GPixelRgn pixel_rgn;
-  GDrawable *drawable;
+  GimpPixelRgn pixel_rgn;
+  GimpDrawable *drawable;
   
 #ifdef XWD_DEBUG
   printf ("load_xwd_f2_d24_b32 (%s)\n", filename);
@@ -1508,7 +1472,7 @@ load_xwd_f2_d24_b32 (char            *filename,
   width = xwdhdr->l_pixmap_width;
   height = xwdhdr->l_pixmap_height;
   
-  image_ID = create_new_image (filename, width, height, RGB,
+  image_ID = create_new_image (filename, width, height, GIMP_RGB,
 			       &layer_ID, &drawable, &pixel_rgn);
   
   tile_height = gimp_tile_height ();
@@ -1602,7 +1566,7 @@ load_xwd_f2_d24_b32 (char            *filename,
 	  for (j = 0; j < linepad; j++)
 	    getc (ifp);
 	  
-	  if ((l_run_mode != RUN_NONINTERACTIVE) && ((i % 20) == 0))
+	  if ((l_run_mode != GIMP_RUN_NONINTERACTIVE) && ((i % 20) == 0))
 	    gimp_progress_update ((double)(i+1) / (double)height);
 	  
 	  if ((scan_lines == tile_height) || ((i+1) == height))
@@ -1651,7 +1615,7 @@ load_xwd_f2_d24_b32 (char            *filename,
 	  for (j = 0; j < linepad; j++)
 	    getc (ifp);
 	  
-	  if ((l_run_mode != RUN_NONINTERACTIVE) && ((i % 20) == 0))
+	  if ((l_run_mode != GIMP_RUN_NONINTERACTIVE) && ((i % 20) == 0))
 	    gimp_progress_update ((double)(i+1) / (double)height);
 	  
 	  if ((scan_lines == tile_height) || ((i+1) == height))
@@ -1699,8 +1663,8 @@ load_xwd_f1_d24_b1 (char            *filename,
   PIXEL_MAP pixel_map;
   int err = 0;
   gint32 layer_ID, image_ID;
-  GPixelRgn pixel_rgn;
-  GDrawable *drawable;
+  GimpPixelRgn pixel_rgn;
+  GimpDrawable *drawable;
   
 #ifdef XWD_DEBUG
   printf ("load_xwd_f1_d24_b1 (%s)\n", filename);
@@ -1714,7 +1678,7 @@ load_xwd_f1_d24_b1 (char            *filename,
   indexed = (xwdhdr->l_pixmap_depth <= 8);
   bytes_per_pixel = (indexed ? 1 : 3);
   
-  image_ID = create_new_image (filename, width, height, indexed ? INDEXED : RGB,
+  image_ID = create_new_image (filename, width, height, indexed ? GIMP_INDEXED : GIMP_RGB,
 			       &layer_ID, &drawable, &pixel_rgn);
   
   tile_height = gimp_tile_height ();
@@ -1907,7 +1871,7 @@ load_xwd_f1_d24_b1 (char            *filename,
 	   }
        }
      
-     if (l_run_mode != RUN_NONINTERACTIVE)
+     if (l_run_mode != GIMP_RUN_NONINTERACTIVE)
        gimp_progress_update ((double)(tile_end) / (double)(height));
      
      gimp_pixel_rgn_set_rect (&pixel_rgn, data, 0, tile_start,
@@ -1937,9 +1901,9 @@ save_index (FILE    *ofp,
   unsigned char *data, *src, *cmap;
   L_XWDFILEHEADER xwdhdr;
   L_XWDCOLOR xwdcolmap[256];
-  GPixelRgn pixel_rgn;
-  GDrawable *drawable;
-  GDrawableType drawable_type;
+  GimpPixelRgn pixel_rgn;
+  GimpDrawable *drawable;
+  GimpImageType drawable_type;
   
 #ifdef XWD_DEBUG
   printf ("save_index ()\n");
@@ -2032,7 +1996,7 @@ save_index (FILE    *ofp,
       if (linepad) fwrite ((char *)&tmp, linepad, 1, ofp);
       src += width;
       
-      if ((l_run_mode != RUN_NONINTERACTIVE) && ((i % 20) == 0))
+      if ((l_run_mode != GIMP_RUN_NONINTERACTIVE) && ((i % 20) == 0))
 	gimp_progress_update ((double) i / (double) height);
     }
   g_free (data);
@@ -2057,9 +2021,9 @@ save_rgb (FILE   *ofp,
   long tmp = 0;
   unsigned char *data, *src;
   L_XWDFILEHEADER xwdhdr;
-  GPixelRgn pixel_rgn;
-  GDrawable *drawable;
-  GDrawableType drawable_type;
+  GimpPixelRgn pixel_rgn;
+  GimpDrawable *drawable;
+  GimpImageType drawable_type;
 
 #ifdef XWD_DEBUG
   printf ("save_rgb ()\n");
@@ -2121,7 +2085,7 @@ save_rgb (FILE   *ofp,
       if (linepad) fwrite ((char *)&tmp, linepad, 1, ofp);
       src += width*3;
       
-      if ((l_run_mode != RUN_NONINTERACTIVE) && ((i % 20) == 0))
+      if ((l_run_mode != GIMP_RUN_NONINTERACTIVE) && ((i % 20) == 0))
 	gimp_progress_update ((double) i / (double) height);
     }
   g_free (data);
